SET LOCAL yb_non_ddl_txn_for_sys_tables_allowed TO true;

DO $$
  DECLARE pg_version VARCHAR;
  DECLARE platform VARCHAR;
  DECLARE en_us_utf8 VARCHAR;
BEGIN
  -- The collation "en_US.utf8" on Linux is called "en_US.UTF-8" on Mac OS.
  SELECT version() into pg_version;
  platform = substr(pg_version, strpos(pg_version, ' on ') + 3);
  platform = substr(platform, 1, strpos(platform, ', compiled by') - 1);
  IF platform LIKE '%linux%' THEN
    en_us_utf8 = 'en_US.utf8';
  ELSIF platform LIKE '%apple%' THEN
    en_us_utf8 = 'en_US.UTF-8';
  ELSE
    RAISE EXCEPTION 'unknown platform %', platform;
  END IF;

  -- Instead of loading collations via pg_import_system_collations, we use PL/pgSQL to
  -- improve performance by doing direct inserts.
  IF NOT EXISTS (
    -- All the collations are batch inserted in a transaction so we only need to check one
    -- of them for existence.
    SELECT FROM pg_catalog.pg_collation
      WHERE collname = en_us_utf8 AND collencoding = 6 AND collnamespace = 11
  ) THEN
    -- Use CTE (Common Table Expression) for temporary result set.
    WITH tmp_oids (pg_coll_oid) AS (
      -- Populate pg_collation table and return the auto-generated OIDs. The collations
      -- are listed in ascending order based upon their initdb OIDs. We assume that during
      -- upgrade postgres will allocate OIDs in ascending order and therefore the auto-generated
      -- collation OIDs will be in the same order of their initdb OIDs.
      INSERT INTO pg_catalog.pg_collation (
        collname, collnamespace, collowner, collprovider,
        collencoding, collcollate, collctype, collversion
      ) VALUES
        (en_us_utf8, 11, 10, 'c', 6, en_us_utf8, en_us_utf8, NULL),
        ('en_US', 11, 10, 'c', 6, en_us_utf8, en_us_utf8, NULL),
        ('und-x-icu', 11, 10, 'i', -1, 'und', 'und', '153.14'),
        ('af-x-icu', 11, 10, 'i', -1, 'af', 'af', '153.14.37'),
        ('af-NA-x-icu', 11, 10, 'i', -1, 'af-NA', 'af-NA', '153.14.37'),
        ('af-ZA-x-icu', 11, 10, 'i', -1, 'af-ZA', 'af-ZA', '153.14.37'),
        ('agq-x-icu', 11, 10, 'i', -1, 'agq', 'agq', '153.14'),
        ('agq-CM-x-icu', 11, 10, 'i', -1, 'agq-CM', 'agq-CM', '153.14'),
        ('ak-x-icu', 11, 10, 'i', -1, 'ak', 'ak', '153.14'),
        ('ak-GH-x-icu', 11, 10, 'i', -1, 'ak-GH', 'ak-GH', '153.14'),
        ('am-x-icu', 11, 10, 'i', -1, 'am', 'am', '153.14.37'),
        ('am-ET-x-icu', 11, 10, 'i', -1, 'am-ET', 'am-ET', '153.14.37'),
        ('ar-x-icu', 11, 10, 'i', -1, 'ar', 'ar', '153.14.37'),
        ('ar-001-x-icu', 11, 10, 'i', -1, 'ar-001', 'ar-001', '153.14.37'),
        ('ar-AE-x-icu', 11, 10, 'i', -1, 'ar-AE', 'ar-AE', '153.14.37'),
        ('ar-BH-x-icu', 11, 10, 'i', -1, 'ar-BH', 'ar-BH', '153.14.37'),
        ('ar-DJ-x-icu', 11, 10, 'i', -1, 'ar-DJ', 'ar-DJ', '153.14.37'),
        ('ar-DZ-x-icu', 11, 10, 'i', -1, 'ar-DZ', 'ar-DZ', '153.14.37'),
        ('ar-EG-x-icu', 11, 10, 'i', -1, 'ar-EG', 'ar-EG', '153.14.37'),
        ('ar-EH-x-icu', 11, 10, 'i', -1, 'ar-EH', 'ar-EH', '153.14.37'),
        ('ar-ER-x-icu', 11, 10, 'i', -1, 'ar-ER', 'ar-ER', '153.14.37'),
        ('ar-IL-x-icu', 11, 10, 'i', -1, 'ar-IL', 'ar-IL', '153.14.37'),
        ('ar-IQ-x-icu', 11, 10, 'i', -1, 'ar-IQ', 'ar-IQ', '153.14.37'),
        ('ar-JO-x-icu', 11, 10, 'i', -1, 'ar-JO', 'ar-JO', '153.14.37'),
        ('ar-KM-x-icu', 11, 10, 'i', -1, 'ar-KM', 'ar-KM', '153.14.37'),
        ('ar-KW-x-icu', 11, 10, 'i', -1, 'ar-KW', 'ar-KW', '153.14.37'),
        ('ar-LB-x-icu', 11, 10, 'i', -1, 'ar-LB', 'ar-LB', '153.14.37'),
        ('ar-LY-x-icu', 11, 10, 'i', -1, 'ar-LY', 'ar-LY', '153.14.37'),
        ('ar-MA-x-icu', 11, 10, 'i', -1, 'ar-MA', 'ar-MA', '153.14.37'),
        ('ar-MR-x-icu', 11, 10, 'i', -1, 'ar-MR', 'ar-MR', '153.14.37'),
        ('ar-OM-x-icu', 11, 10, 'i', -1, 'ar-OM', 'ar-OM', '153.14.37'),
        ('ar-PS-x-icu', 11, 10, 'i', -1, 'ar-PS', 'ar-PS', '153.14.37'),
        ('ar-QA-x-icu', 11, 10, 'i', -1, 'ar-QA', 'ar-QA', '153.14.37'),
        ('ar-SA-x-icu', 11, 10, 'i', -1, 'ar-SA', 'ar-SA', '153.14.37'),
        ('ar-SD-x-icu', 11, 10, 'i', -1, 'ar-SD', 'ar-SD', '153.14.37'),
        ('ar-SO-x-icu', 11, 10, 'i', -1, 'ar-SO', 'ar-SO', '153.14.37'),
        ('ar-SS-x-icu', 11, 10, 'i', -1, 'ar-SS', 'ar-SS', '153.14.37'),
        ('ar-SY-x-icu', 11, 10, 'i', -1, 'ar-SY', 'ar-SY', '153.14.37'),
        ('ar-TD-x-icu', 11, 10, 'i', -1, 'ar-TD', 'ar-TD', '153.14.37'),
        ('ar-TN-x-icu', 11, 10, 'i', -1, 'ar-TN', 'ar-TN', '153.14.37'),
        ('ar-YE-x-icu', 11, 10, 'i', -1, 'ar-YE', 'ar-YE', '153.14.37'),
        ('as-x-icu', 11, 10, 'i', -1, 'as', 'as', '153.14.37'),
        ('as-IN-x-icu', 11, 10, 'i', -1, 'as-IN', 'as-IN', '153.14.37'),
        ('asa-x-icu', 11, 10, 'i', -1, 'asa', 'asa', '153.14'),
        ('asa-TZ-x-icu', 11, 10, 'i', -1, 'asa-TZ', 'asa-TZ', '153.14'),
        ('ast-x-icu', 11, 10, 'i', -1, 'ast', 'ast', '153.14'),
        ('ast-ES-x-icu', 11, 10, 'i', -1, 'ast-ES', 'ast-ES', '153.14'),
        ('az-x-icu', 11, 10, 'i', -1, 'az', 'az', '153.14.37'),
        ('az-Cyrl-x-icu', 11, 10, 'i', -1, 'az-Cyrl', 'az-Cyrl', '153.14.37'),
        ('az-Cyrl-AZ-x-icu', 11, 10, 'i', -1, 'az-Cyrl-AZ', 'az-Cyrl-AZ', '153.14.37'),
        ('az-Latn-x-icu', 11, 10, 'i', -1, 'az-Latn', 'az-Latn', '153.14.37'),
        ('az-Latn-AZ-x-icu', 11, 10, 'i', -1, 'az-Latn-AZ', 'az-Latn-AZ', '153.14.37'),
        ('bas-x-icu', 11, 10, 'i', -1, 'bas', 'bas', '153.14'),
        ('bas-CM-x-icu', 11, 10, 'i', -1, 'bas-CM', 'bas-CM', '153.14'),
        ('be-x-icu', 11, 10, 'i', -1, 'be', 'be', '153.14.37'),
        ('be-BY-x-icu', 11, 10, 'i', -1, 'be-BY', 'be-BY', '153.14.37'),
        ('bem-x-icu', 11, 10, 'i', -1, 'bem', 'bem', '153.14'),
        ('bem-ZM-x-icu', 11, 10, 'i', -1, 'bem-ZM', 'bem-ZM', '153.14'),
        ('bez-x-icu', 11, 10, 'i', -1, 'bez', 'bez', '153.14'),
        ('bez-TZ-x-icu', 11, 10, 'i', -1, 'bez-TZ', 'bez-TZ', '153.14'),
        ('bg-x-icu', 11, 10, 'i', -1, 'bg', 'bg', '153.14.37'),
        ('bg-BG-x-icu', 11, 10, 'i', -1, 'bg-BG', 'bg-BG', '153.14.37'),
        ('bm-x-icu', 11, 10, 'i', -1, 'bm', 'bm', '153.14'),
        ('bm-ML-x-icu', 11, 10, 'i', -1, 'bm-ML', 'bm-ML', '153.14'),
        ('bn-x-icu', 11, 10, 'i', -1, 'bn', 'bn', '153.14.37'),
        ('bn-BD-x-icu', 11, 10, 'i', -1, 'bn-BD', 'bn-BD', '153.14.37'),
        ('bn-IN-x-icu', 11, 10, 'i', -1, 'bn-IN', 'bn-IN', '153.14.37'),
        ('bo-x-icu', 11, 10, 'i', -1, 'bo', 'bo', '153.14'),
        ('bo-CN-x-icu', 11, 10, 'i', -1, 'bo-CN', 'bo-CN', '153.14'),
        ('bo-IN-x-icu', 11, 10, 'i', -1, 'bo-IN', 'bo-IN', '153.14'),
        ('br-x-icu', 11, 10, 'i', -1, 'br', 'br', '153.14'),
        ('br-FR-x-icu', 11, 10, 'i', -1, 'br-FR', 'br-FR', '153.14'),
        ('brx-x-icu', 11, 10, 'i', -1, 'brx', 'brx', '153.14'),
        ('brx-IN-x-icu', 11, 10, 'i', -1, 'brx-IN', 'brx-IN', '153.14'),
        ('bs-x-icu', 11, 10, 'i', -1, 'bs', 'bs', '153.14.37'),
        ('bs-Cyrl-x-icu', 11, 10, 'i', -1, 'bs-Cyrl', 'bs-Cyrl', '153.14.37'),
        ('bs-Cyrl-BA-x-icu', 11, 10, 'i', -1, 'bs-Cyrl-BA', 'bs-Cyrl-BA', '153.14.37'),
        ('bs-Latn-x-icu', 11, 10, 'i', -1, 'bs-Latn', 'bs-Latn', '153.14.37'),
        ('bs-Latn-BA-x-icu', 11, 10, 'i', -1, 'bs-Latn-BA', 'bs-Latn-BA', '153.14.37'),
        ('ca-x-icu', 11, 10, 'i', -1, 'ca', 'ca', '153.14'),
        ('ca-AD-x-icu', 11, 10, 'i', -1, 'ca-AD', 'ca-AD', '153.14'),
        ('ca-ES-x-icu', 11, 10, 'i', -1, 'ca-ES', 'ca-ES', '153.14'),
        ('ca-FR-x-icu', 11, 10, 'i', -1, 'ca-FR', 'ca-FR', '153.14'),
        ('ca-IT-x-icu', 11, 10, 'i', -1, 'ca-IT', 'ca-IT', '153.14'),
        ('ccp-x-icu', 11, 10, 'i', -1, 'ccp', 'ccp', '153.14'),
        ('ccp-BD-x-icu', 11, 10, 'i', -1, 'ccp-BD', 'ccp-BD', '153.14'),
        ('ccp-IN-x-icu', 11, 10, 'i', -1, 'ccp-IN', 'ccp-IN', '153.14'),
        ('ce-x-icu', 11, 10, 'i', -1, 'ce', 'ce', '153.14'),
        ('ce-RU-x-icu', 11, 10, 'i', -1, 'ce-RU', 'ce-RU', '153.14'),
        ('ceb-x-icu', 11, 10, 'i', -1, 'ceb', 'ceb', '153.14.37'),
        ('ceb-PH-x-icu', 11, 10, 'i', -1, 'ceb-PH', 'ceb-PH', '153.14.37'),
        ('cgg-x-icu', 11, 10, 'i', -1, 'cgg', 'cgg', '153.14'),
        ('cgg-UG-x-icu', 11, 10, 'i', -1, 'cgg-UG', 'cgg-UG', '153.14'),
        ('chr-x-icu', 11, 10, 'i', -1, 'chr', 'chr', '153.14.37'),
        ('chr-US-x-icu', 11, 10, 'i', -1, 'chr-US', 'chr-US', '153.14.37'),
        ('ckb-x-icu', 11, 10, 'i', -1, 'ckb', 'ckb', '153.14'),
        ('ckb-IQ-x-icu', 11, 10, 'i', -1, 'ckb-IQ', 'ckb-IQ', '153.14'),
        ('ckb-IR-x-icu', 11, 10, 'i', -1, 'ckb-IR', 'ckb-IR', '153.14'),
        ('cs-x-icu', 11, 10, 'i', -1, 'cs', 'cs', '153.14.37'),
        ('cs-CZ-x-icu', 11, 10, 'i', -1, 'cs-CZ', 'cs-CZ', '153.14.37'),
        ('cy-x-icu', 11, 10, 'i', -1, 'cy', 'cy', '153.14.37'),
        ('cy-GB-x-icu', 11, 10, 'i', -1, 'cy-GB', 'cy-GB', '153.14.37'),
        ('da-x-icu', 11, 10, 'i', -1, 'da', 'da', '153.14.37'),
        ('da-DK-x-icu', 11, 10, 'i', -1, 'da-DK', 'da-DK', '153.14.37'),
        ('da-GL-x-icu', 11, 10, 'i', -1, 'da-GL', 'da-GL', '153.14.37'),
        ('dav-x-icu', 11, 10, 'i', -1, 'dav', 'dav', '153.14'),
        ('dav-KE-x-icu', 11, 10, 'i', -1, 'dav-KE', 'dav-KE', '153.14'),
        ('de-x-icu', 11, 10, 'i', -1, 'de', 'de', '153.14'),
        ('de-AT-x-icu', 11, 10, 'i', -1, 'de-AT', 'de-AT', '153.14'),
        ('de-BE-x-icu', 11, 10, 'i', -1, 'de-BE', 'de-BE', '153.14'),
        ('de-CH-x-icu', 11, 10, 'i', -1, 'de-CH', 'de-CH', '153.14'),
        ('de-DE-x-icu', 11, 10, 'i', -1, 'de-DE', 'de-DE', '153.14'),
        ('de-IT-x-icu', 11, 10, 'i', -1, 'de-IT', 'de-IT', '153.14'),
        ('de-LI-x-icu', 11, 10, 'i', -1, 'de-LI', 'de-LI', '153.14'),
        ('de-LU-x-icu', 11, 10, 'i', -1, 'de-LU', 'de-LU', '153.14'),
        ('dje-x-icu', 11, 10, 'i', -1, 'dje', 'dje', '153.14'),
        ('dje-NE-x-icu', 11, 10, 'i', -1, 'dje-NE', 'dje-NE', '153.14'),
        ('dsb-x-icu', 11, 10, 'i', -1, 'dsb', 'dsb', '153.14.37'),
        ('dsb-DE-x-icu', 11, 10, 'i', -1, 'dsb-DE', 'dsb-DE', '153.14.37'),
        ('dua-x-icu', 11, 10, 'i', -1, 'dua', 'dua', '153.14'),
        ('dua-CM-x-icu', 11, 10, 'i', -1, 'dua-CM', 'dua-CM', '153.14'),
        ('dyo-x-icu', 11, 10, 'i', -1, 'dyo', 'dyo', '153.14'),
        ('dyo-SN-x-icu', 11, 10, 'i', -1, 'dyo-SN', 'dyo-SN', '153.14'),
        ('dz-x-icu', 11, 10, 'i', -1, 'dz', 'dz', '153.14'),
        ('dz-BT-x-icu', 11, 10, 'i', -1, 'dz-BT', 'dz-BT', '153.14'),
        ('ebu-x-icu', 11, 10, 'i', -1, 'ebu', 'ebu', '153.14'),
        ('ebu-KE-x-icu', 11, 10, 'i', -1, 'ebu-KE', 'ebu-KE', '153.14'),
        ('ee-x-icu', 11, 10, 'i', -1, 'ee', 'ee', '153.14.37'),
        ('ee-GH-x-icu', 11, 10, 'i', -1, 'ee-GH', 'ee-GH', '153.14.37'),
        ('ee-TG-x-icu', 11, 10, 'i', -1, 'ee-TG', 'ee-TG', '153.14.37'),
        ('el-x-icu', 11, 10, 'i', -1, 'el', 'el', '153.14.37'),
        ('el-CY-x-icu', 11, 10, 'i', -1, 'el-CY', 'el-CY', '153.14.37'),
        ('el-GR-x-icu', 11, 10, 'i', -1, 'el-GR', 'el-GR', '153.14.37'),
        ('en-x-icu', 11, 10, 'i', -1, 'en', 'en', '153.14'),
        ('en-001-x-icu', 11, 10, 'i', -1, 'en-001', 'en-001', '153.14'),
        ('en-150-x-icu', 11, 10, 'i', -1, 'en-150', 'en-150', '153.14'),
        ('en-AE-x-icu', 11, 10, 'i', -1, 'en-AE', 'en-AE', '153.14'),
        ('en-AG-x-icu', 11, 10, 'i', -1, 'en-AG', 'en-AG', '153.14'),
        ('en-AI-x-icu', 11, 10, 'i', -1, 'en-AI', 'en-AI', '153.14'),
        ('en-AS-x-icu', 11, 10, 'i', -1, 'en-AS', 'en-AS', '153.14'),
        ('en-AT-x-icu', 11, 10, 'i', -1, 'en-AT', 'en-AT', '153.14'),
        ('en-AU-x-icu', 11, 10, 'i', -1, 'en-AU', 'en-AU', '153.14'),
        ('en-BB-x-icu', 11, 10, 'i', -1, 'en-BB', 'en-BB', '153.14'),
        ('en-BE-x-icu', 11, 10, 'i', -1, 'en-BE', 'en-BE', '153.14'),
        ('en-BI-x-icu', 11, 10, 'i', -1, 'en-BI', 'en-BI', '153.14'),
        ('en-BM-x-icu', 11, 10, 'i', -1, 'en-BM', 'en-BM', '153.14'),
        ('en-BS-x-icu', 11, 10, 'i', -1, 'en-BS', 'en-BS', '153.14'),
        ('en-BW-x-icu', 11, 10, 'i', -1, 'en-BW', 'en-BW', '153.14'),
        ('en-BZ-x-icu', 11, 10, 'i', -1, 'en-BZ', 'en-BZ', '153.14'),
        ('en-CA-x-icu', 11, 10, 'i', -1, 'en-CA', 'en-CA', '153.14'),
        ('en-CC-x-icu', 11, 10, 'i', -1, 'en-CC', 'en-CC', '153.14'),
        ('en-CH-x-icu', 11, 10, 'i', -1, 'en-CH', 'en-CH', '153.14'),
        ('en-CK-x-icu', 11, 10, 'i', -1, 'en-CK', 'en-CK', '153.14'),
        ('en-CM-x-icu', 11, 10, 'i', -1, 'en-CM', 'en-CM', '153.14'),
        ('en-CX-x-icu', 11, 10, 'i', -1, 'en-CX', 'en-CX', '153.14'),
        ('en-CY-x-icu', 11, 10, 'i', -1, 'en-CY', 'en-CY', '153.14'),
        ('en-DE-x-icu', 11, 10, 'i', -1, 'en-DE', 'en-DE', '153.14'),
        ('en-DG-x-icu', 11, 10, 'i', -1, 'en-DG', 'en-DG', '153.14'),
        ('en-DK-x-icu', 11, 10, 'i', -1, 'en-DK', 'en-DK', '153.14'),
        ('en-DM-x-icu', 11, 10, 'i', -1, 'en-DM', 'en-DM', '153.14'),
        ('en-ER-x-icu', 11, 10, 'i', -1, 'en-ER', 'en-ER', '153.14'),
        ('en-FI-x-icu', 11, 10, 'i', -1, 'en-FI', 'en-FI', '153.14'),
        ('en-FJ-x-icu', 11, 10, 'i', -1, 'en-FJ', 'en-FJ', '153.14'),
        ('en-FK-x-icu', 11, 10, 'i', -1, 'en-FK', 'en-FK', '153.14'),
        ('en-FM-x-icu', 11, 10, 'i', -1, 'en-FM', 'en-FM', '153.14'),
        ('en-GB-x-icu', 11, 10, 'i', -1, 'en-GB', 'en-GB', '153.14'),
        ('en-GD-x-icu', 11, 10, 'i', -1, 'en-GD', 'en-GD', '153.14'),
        ('en-GG-x-icu', 11, 10, 'i', -1, 'en-GG', 'en-GG', '153.14'),
        ('en-GH-x-icu', 11, 10, 'i', -1, 'en-GH', 'en-GH', '153.14'),
        ('en-GI-x-icu', 11, 10, 'i', -1, 'en-GI', 'en-GI', '153.14'),
        ('en-GM-x-icu', 11, 10, 'i', -1, 'en-GM', 'en-GM', '153.14'),
        ('en-GU-x-icu', 11, 10, 'i', -1, 'en-GU', 'en-GU', '153.14'),
        ('en-GY-x-icu', 11, 10, 'i', -1, 'en-GY', 'en-GY', '153.14'),
        ('en-HK-x-icu', 11, 10, 'i', -1, 'en-HK', 'en-HK', '153.14'),
        ('en-IE-x-icu', 11, 10, 'i', -1, 'en-IE', 'en-IE', '153.14'),
        ('en-IL-x-icu', 11, 10, 'i', -1, 'en-IL', 'en-IL', '153.14'),
        ('en-IM-x-icu', 11, 10, 'i', -1, 'en-IM', 'en-IM', '153.14'),
        ('en-IN-x-icu', 11, 10, 'i', -1, 'en-IN', 'en-IN', '153.14'),
        ('en-IO-x-icu', 11, 10, 'i', -1, 'en-IO', 'en-IO', '153.14'),
        ('en-JE-x-icu', 11, 10, 'i', -1, 'en-JE', 'en-JE', '153.14'),
        ('en-JM-x-icu', 11, 10, 'i', -1, 'en-JM', 'en-JM', '153.14'),
        ('en-KE-x-icu', 11, 10, 'i', -1, 'en-KE', 'en-KE', '153.14'),
        ('en-KI-x-icu', 11, 10, 'i', -1, 'en-KI', 'en-KI', '153.14'),
        ('en-KN-x-icu', 11, 10, 'i', -1, 'en-KN', 'en-KN', '153.14'),
        ('en-KY-x-icu', 11, 10, 'i', -1, 'en-KY', 'en-KY', '153.14'),
        ('en-LC-x-icu', 11, 10, 'i', -1, 'en-LC', 'en-LC', '153.14'),
        ('en-LR-x-icu', 11, 10, 'i', -1, 'en-LR', 'en-LR', '153.14'),
        ('en-LS-x-icu', 11, 10, 'i', -1, 'en-LS', 'en-LS', '153.14'),
        ('en-MG-x-icu', 11, 10, 'i', -1, 'en-MG', 'en-MG', '153.14'),
        ('en-MH-x-icu', 11, 10, 'i', -1, 'en-MH', 'en-MH', '153.14'),
        ('en-MO-x-icu', 11, 10, 'i', -1, 'en-MO', 'en-MO', '153.14'),
        ('en-MP-x-icu', 11, 10, 'i', -1, 'en-MP', 'en-MP', '153.14'),
        ('en-MS-x-icu', 11, 10, 'i', -1, 'en-MS', 'en-MS', '153.14'),
        ('en-MT-x-icu', 11, 10, 'i', -1, 'en-MT', 'en-MT', '153.14'),
        ('en-MU-x-icu', 11, 10, 'i', -1, 'en-MU', 'en-MU', '153.14'),
        ('en-MW-x-icu', 11, 10, 'i', -1, 'en-MW', 'en-MW', '153.14'),
        ('en-MY-x-icu', 11, 10, 'i', -1, 'en-MY', 'en-MY', '153.14'),
        ('en-NA-x-icu', 11, 10, 'i', -1, 'en-NA', 'en-NA', '153.14'),
        ('en-NF-x-icu', 11, 10, 'i', -1, 'en-NF', 'en-NF', '153.14'),
        ('en-NG-x-icu', 11, 10, 'i', -1, 'en-NG', 'en-NG', '153.14'),
        ('en-NL-x-icu', 11, 10, 'i', -1, 'en-NL', 'en-NL', '153.14'),
        ('en-NR-x-icu', 11, 10, 'i', -1, 'en-NR', 'en-NR', '153.14'),
        ('en-NU-x-icu', 11, 10, 'i', -1, 'en-NU', 'en-NU', '153.14'),
        ('en-NZ-x-icu', 11, 10, 'i', -1, 'en-NZ', 'en-NZ', '153.14'),
        ('en-PG-x-icu', 11, 10, 'i', -1, 'en-PG', 'en-PG', '153.14'),
        ('en-PH-x-icu', 11, 10, 'i', -1, 'en-PH', 'en-PH', '153.14'),
        ('en-PK-x-icu', 11, 10, 'i', -1, 'en-PK', 'en-PK', '153.14'),
        ('en-PN-x-icu', 11, 10, 'i', -1, 'en-PN', 'en-PN', '153.14'),
        ('en-PR-x-icu', 11, 10, 'i', -1, 'en-PR', 'en-PR', '153.14'),
        ('en-PW-x-icu', 11, 10, 'i', -1, 'en-PW', 'en-PW', '153.14'),
        ('en-RW-x-icu', 11, 10, 'i', -1, 'en-RW', 'en-RW', '153.14'),
        ('en-SB-x-icu', 11, 10, 'i', -1, 'en-SB', 'en-SB', '153.14'),
        ('en-SC-x-icu', 11, 10, 'i', -1, 'en-SC', 'en-SC', '153.14'),
        ('en-SD-x-icu', 11, 10, 'i', -1, 'en-SD', 'en-SD', '153.14'),
        ('en-SE-x-icu', 11, 10, 'i', -1, 'en-SE', 'en-SE', '153.14'),
        ('en-SG-x-icu', 11, 10, 'i', -1, 'en-SG', 'en-SG', '153.14'),
        ('en-SH-x-icu', 11, 10, 'i', -1, 'en-SH', 'en-SH', '153.14'),
        ('en-SI-x-icu', 11, 10, 'i', -1, 'en-SI', 'en-SI', '153.14'),
        ('en-SL-x-icu', 11, 10, 'i', -1, 'en-SL', 'en-SL', '153.14'),
        ('en-SS-x-icu', 11, 10, 'i', -1, 'en-SS', 'en-SS', '153.14'),
        ('en-SX-x-icu', 11, 10, 'i', -1, 'en-SX', 'en-SX', '153.14'),
        ('en-SZ-x-icu', 11, 10, 'i', -1, 'en-SZ', 'en-SZ', '153.14'),
        ('en-TC-x-icu', 11, 10, 'i', -1, 'en-TC', 'en-TC', '153.14'),
        ('en-TK-x-icu', 11, 10, 'i', -1, 'en-TK', 'en-TK', '153.14'),
        ('en-TO-x-icu', 11, 10, 'i', -1, 'en-TO', 'en-TO', '153.14'),
        ('en-TT-x-icu', 11, 10, 'i', -1, 'en-TT', 'en-TT', '153.14'),
        ('en-TV-x-icu', 11, 10, 'i', -1, 'en-TV', 'en-TV', '153.14'),
        ('en-TZ-x-icu', 11, 10, 'i', -1, 'en-TZ', 'en-TZ', '153.14'),
        ('en-UG-x-icu', 11, 10, 'i', -1, 'en-UG', 'en-UG', '153.14'),
        ('en-UM-x-icu', 11, 10, 'i', -1, 'en-UM', 'en-UM', '153.14'),
        ('en-US-x-icu', 11, 10, 'i', -1, 'en-US', 'en-US', '153.14'),
        ('en-US-u-va-posix-x-icu', 11, 10, 'i', -1, 'en-US-u-va-posix', 'en-US-u-va-posix', '153.14.37'),
        ('en-VC-x-icu', 11, 10, 'i', -1, 'en-VC', 'en-VC', '153.14'),
        ('en-VG-x-icu', 11, 10, 'i', -1, 'en-VG', 'en-VG', '153.14'),
        ('en-VI-x-icu', 11, 10, 'i', -1, 'en-VI', 'en-VI', '153.14'),
        ('en-VU-x-icu', 11, 10, 'i', -1, 'en-VU', 'en-VU', '153.14'),
        ('en-WS-x-icu', 11, 10, 'i', -1, 'en-WS', 'en-WS', '153.14'),
        ('en-ZA-x-icu', 11, 10, 'i', -1, 'en-ZA', 'en-ZA', '153.14'),
        ('en-ZM-x-icu', 11, 10, 'i', -1, 'en-ZM', 'en-ZM', '153.14'),
        ('en-ZW-x-icu', 11, 10, 'i', -1, 'en-ZW', 'en-ZW', '153.14'),
        ('eo-x-icu', 11, 10, 'i', -1, 'eo', 'eo', '153.14.37'),
        ('eo-001-x-icu', 11, 10, 'i', -1, 'eo-001', 'eo-001', '153.14.37'),
        ('es-x-icu', 11, 10, 'i', -1, 'es', 'es', '153.14.37'),
        ('es-419-x-icu', 11, 10, 'i', -1, 'es-419', 'es-419', '153.14.37'),
        ('es-AR-x-icu', 11, 10, 'i', -1, 'es-AR', 'es-AR', '153.14.37'),
        ('es-BO-x-icu', 11, 10, 'i', -1, 'es-BO', 'es-BO', '153.14.37'),
        ('es-BR-x-icu', 11, 10, 'i', -1, 'es-BR', 'es-BR', '153.14.37'),
        ('es-BZ-x-icu', 11, 10, 'i', -1, 'es-BZ', 'es-BZ', '153.14.37'),
        ('es-CL-x-icu', 11, 10, 'i', -1, 'es-CL', 'es-CL', '153.14.37'),
        ('es-CO-x-icu', 11, 10, 'i', -1, 'es-CO', 'es-CO', '153.14.37'),
        ('es-CR-x-icu', 11, 10, 'i', -1, 'es-CR', 'es-CR', '153.14.37'),
        ('es-CU-x-icu', 11, 10, 'i', -1, 'es-CU', 'es-CU', '153.14.37'),
        ('es-DO-x-icu', 11, 10, 'i', -1, 'es-DO', 'es-DO', '153.14.37'),
        ('es-EA-x-icu', 11, 10, 'i', -1, 'es-EA', 'es-EA', '153.14.37'),
        ('es-EC-x-icu', 11, 10, 'i', -1, 'es-EC', 'es-EC', '153.14.37'),
        ('es-ES-x-icu', 11, 10, 'i', -1, 'es-ES', 'es-ES', '153.14.37'),
        ('es-GQ-x-icu', 11, 10, 'i', -1, 'es-GQ', 'es-GQ', '153.14.37'),
        ('es-GT-x-icu', 11, 10, 'i', -1, 'es-GT', 'es-GT', '153.14.37'),
        ('es-HN-x-icu', 11, 10, 'i', -1, 'es-HN', 'es-HN', '153.14.37'),
        ('es-IC-x-icu', 11, 10, 'i', -1, 'es-IC', 'es-IC', '153.14.37'),
        ('es-MX-x-icu', 11, 10, 'i', -1, 'es-MX', 'es-MX', '153.14.37'),
        ('es-NI-x-icu', 11, 10, 'i', -1, 'es-NI', 'es-NI', '153.14.37'),
        ('es-PA-x-icu', 11, 10, 'i', -1, 'es-PA', 'es-PA', '153.14.37'),
        ('es-PE-x-icu', 11, 10, 'i', -1, 'es-PE', 'es-PE', '153.14.37'),
        ('es-PH-x-icu', 11, 10, 'i', -1, 'es-PH', 'es-PH', '153.14.37'),
        ('es-PR-x-icu', 11, 10, 'i', -1, 'es-PR', 'es-PR', '153.14.37'),
        ('es-PY-x-icu', 11, 10, 'i', -1, 'es-PY', 'es-PY', '153.14.37'),
        ('es-SV-x-icu', 11, 10, 'i', -1, 'es-SV', 'es-SV', '153.14.37'),
        ('es-US-x-icu', 11, 10, 'i', -1, 'es-US', 'es-US', '153.14.37'),
        ('es-UY-x-icu', 11, 10, 'i', -1, 'es-UY', 'es-UY', '153.14.37'),
        ('es-VE-x-icu', 11, 10, 'i', -1, 'es-VE', 'es-VE', '153.14.37'),
        ('et-x-icu', 11, 10, 'i', -1, 'et', 'et', '153.14.37'),
        ('et-EE-x-icu', 11, 10, 'i', -1, 'et-EE', 'et-EE', '153.14.37'),
        ('eu-x-icu', 11, 10, 'i', -1, 'eu', 'eu', '153.14'),
        ('eu-ES-x-icu', 11, 10, 'i', -1, 'eu-ES', 'eu-ES', '153.14'),
        ('ewo-x-icu', 11, 10, 'i', -1, 'ewo', 'ewo', '153.14'),
        ('ewo-CM-x-icu', 11, 10, 'i', -1, 'ewo-CM', 'ewo-CM', '153.14'),
        ('fa-x-icu', 11, 10, 'i', -1, 'fa', 'fa', '153.14.37'),
        ('fa-AF-x-icu', 11, 10, 'i', -1, 'fa-AF', 'fa-AF', '153.14.37'),
        ('fa-IR-x-icu', 11, 10, 'i', -1, 'fa-IR', 'fa-IR', '153.14.37'),
        ('ff-x-icu', 11, 10, 'i', -1, 'ff', 'ff', '153.14'),
        ('ff-Adlm-x-icu', 11, 10, 'i', -1, 'ff-Adlm', 'ff-Adlm', '153.14.37'),
        ('ff-Adlm-BF-x-icu', 11, 10, 'i', -1, 'ff-Adlm-BF', 'ff-Adlm-BF', '153.14.37'),
        ('ff-Adlm-CM-x-icu', 11, 10, 'i', -1, 'ff-Adlm-CM', 'ff-Adlm-CM', '153.14.37'),
        ('ff-Adlm-GH-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GH', 'ff-Adlm-GH', '153.14.37'),
        ('ff-Adlm-GM-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GM', 'ff-Adlm-GM', '153.14.37'),
        ('ff-Adlm-GN-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GN', 'ff-Adlm-GN', '153.14.37'),
        ('ff-Adlm-GW-x-icu', 11, 10, 'i', -1, 'ff-Adlm-GW', 'ff-Adlm-GW', '153.14.37'),
        ('ff-Adlm-LR-x-icu', 11, 10, 'i', -1, 'ff-Adlm-LR', 'ff-Adlm-LR', '153.14.37'),
        ('ff-Adlm-MR-x-icu', 11, 10, 'i', -1, 'ff-Adlm-MR', 'ff-Adlm-MR', '153.14.37'),
        ('ff-Adlm-NE-x-icu', 11, 10, 'i', -1, 'ff-Adlm-NE', 'ff-Adlm-NE', '153.14.37'),
        ('ff-Adlm-NG-x-icu', 11, 10, 'i', -1, 'ff-Adlm-NG', 'ff-Adlm-NG', '153.14.37'),
        ('ff-Adlm-SL-x-icu', 11, 10, 'i', -1, 'ff-Adlm-SL', 'ff-Adlm-SL', '153.14.37'),
        ('ff-Adlm-SN-x-icu', 11, 10, 'i', -1, 'ff-Adlm-SN', 'ff-Adlm-SN', '153.14.37'),
        ('ff-Latn-x-icu', 11, 10, 'i', -1, 'ff-Latn', 'ff-Latn', '153.14'),
        ('ff-Latn-BF-x-icu', 11, 10, 'i', -1, 'ff-Latn-BF', 'ff-Latn-BF', '153.14'),
        ('ff-Latn-CM-x-icu', 11, 10, 'i', -1, 'ff-Latn-CM', 'ff-Latn-CM', '153.14'),
        ('ff-Latn-GH-x-icu', 11, 10, 'i', -1, 'ff-Latn-GH', 'ff-Latn-GH', '153.14'),
        ('ff-Latn-GM-x-icu', 11, 10, 'i', -1, 'ff-Latn-GM', 'ff-Latn-GM', '153.14'),
        ('ff-Latn-GN-x-icu', 11, 10, 'i', -1, 'ff-Latn-GN', 'ff-Latn-GN', '153.14'),
        ('ff-Latn-GW-x-icu', 11, 10, 'i', -1, 'ff-Latn-GW', 'ff-Latn-GW', '153.14'),
        ('ff-Latn-LR-x-icu', 11, 10, 'i', -1, 'ff-Latn-LR', 'ff-Latn-LR', '153.14'),
        ('ff-Latn-MR-x-icu', 11, 10, 'i', -1, 'ff-Latn-MR', 'ff-Latn-MR', '153.14'),
        ('ff-Latn-NE-x-icu', 11, 10, 'i', -1, 'ff-Latn-NE', 'ff-Latn-NE', '153.14'),
        ('ff-Latn-NG-x-icu', 11, 10, 'i', -1, 'ff-Latn-NG', 'ff-Latn-NG', '153.14'),
        ('ff-Latn-SL-x-icu', 11, 10, 'i', -1, 'ff-Latn-SL', 'ff-Latn-SL', '153.14'),
        ('ff-Latn-SN-x-icu', 11, 10, 'i', -1, 'ff-Latn-SN', 'ff-Latn-SN', '153.14'),
        ('fi-x-icu', 11, 10, 'i', -1, 'fi', 'fi', '153.14.37'),
        ('fi-FI-x-icu', 11, 10, 'i', -1, 'fi-FI', 'fi-FI', '153.14.37'),
        ('fil-x-icu', 11, 10, 'i', -1, 'fil', 'fil', '153.14.37'),
        ('fil-PH-x-icu', 11, 10, 'i', -1, 'fil-PH', 'fil-PH', '153.14.37'),
        ('fo-x-icu', 11, 10, 'i', -1, 'fo', 'fo', '153.14.37'),
        ('fo-DK-x-icu', 11, 10, 'i', -1, 'fo-DK', 'fo-DK', '153.14.37'),
        ('fo-FO-x-icu', 11, 10, 'i', -1, 'fo-FO', 'fo-FO', '153.14.37'),
        ('fr-x-icu', 11, 10, 'i', -1, 'fr', 'fr', '153.14'),
        ('fr-BE-x-icu', 11, 10, 'i', -1, 'fr-BE', 'fr-BE', '153.14'),
        ('fr-BF-x-icu', 11, 10, 'i', -1, 'fr-BF', 'fr-BF', '153.14'),
        ('fr-BI-x-icu', 11, 10, 'i', -1, 'fr-BI', 'fr-BI', '153.14'),
        ('fr-BJ-x-icu', 11, 10, 'i', -1, 'fr-BJ', 'fr-BJ', '153.14'),
        ('fr-BL-x-icu', 11, 10, 'i', -1, 'fr-BL', 'fr-BL', '153.14'),
        ('fr-CA-x-icu', 11, 10, 'i', -1, 'fr-CA', 'fr-CA', '153.14.37'),
        ('fr-CD-x-icu', 11, 10, 'i', -1, 'fr-CD', 'fr-CD', '153.14'),
        ('fr-CF-x-icu', 11, 10, 'i', -1, 'fr-CF', 'fr-CF', '153.14'),
        ('fr-CG-x-icu', 11, 10, 'i', -1, 'fr-CG', 'fr-CG', '153.14'),
        ('fr-CH-x-icu', 11, 10, 'i', -1, 'fr-CH', 'fr-CH', '153.14'),
        ('fr-CI-x-icu', 11, 10, 'i', -1, 'fr-CI', 'fr-CI', '153.14'),
        ('fr-CM-x-icu', 11, 10, 'i', -1, 'fr-CM', 'fr-CM', '153.14'),
        ('fr-DJ-x-icu', 11, 10, 'i', -1, 'fr-DJ', 'fr-DJ', '153.14'),
        ('fr-DZ-x-icu', 11, 10, 'i', -1, 'fr-DZ', 'fr-DZ', '153.14'),
        ('fr-FR-x-icu', 11, 10, 'i', -1, 'fr-FR', 'fr-FR', '153.14'),
        ('fr-GA-x-icu', 11, 10, 'i', -1, 'fr-GA', 'fr-GA', '153.14'),
        ('fr-GF-x-icu', 11, 10, 'i', -1, 'fr-GF', 'fr-GF', '153.14'),
        ('fr-GN-x-icu', 11, 10, 'i', -1, 'fr-GN', 'fr-GN', '153.14'),
        ('fr-GP-x-icu', 11, 10, 'i', -1, 'fr-GP', 'fr-GP', '153.14'),
        ('fr-GQ-x-icu', 11, 10, 'i', -1, 'fr-GQ', 'fr-GQ', '153.14'),
        ('fr-HT-x-icu', 11, 10, 'i', -1, 'fr-HT', 'fr-HT', '153.14'),
        ('fr-KM-x-icu', 11, 10, 'i', -1, 'fr-KM', 'fr-KM', '153.14'),
        ('fr-LU-x-icu', 11, 10, 'i', -1, 'fr-LU', 'fr-LU', '153.14'),
        ('fr-MA-x-icu', 11, 10, 'i', -1, 'fr-MA', 'fr-MA', '153.14'),
        ('fr-MC-x-icu', 11, 10, 'i', -1, 'fr-MC', 'fr-MC', '153.14'),
        ('fr-MF-x-icu', 11, 10, 'i', -1, 'fr-MF', 'fr-MF', '153.14'),
        ('fr-MG-x-icu', 11, 10, 'i', -1, 'fr-MG', 'fr-MG', '153.14'),
        ('fr-ML-x-icu', 11, 10, 'i', -1, 'fr-ML', 'fr-ML', '153.14'),
        ('fr-MQ-x-icu', 11, 10, 'i', -1, 'fr-MQ', 'fr-MQ', '153.14'),
        ('fr-MR-x-icu', 11, 10, 'i', -1, 'fr-MR', 'fr-MR', '153.14'),
        ('fr-MU-x-icu', 11, 10, 'i', -1, 'fr-MU', 'fr-MU', '153.14'),
        ('fr-NC-x-icu', 11, 10, 'i', -1, 'fr-NC', 'fr-NC', '153.14'),
        ('fr-NE-x-icu', 11, 10, 'i', -1, 'fr-NE', 'fr-NE', '153.14'),
        ('fr-PF-x-icu', 11, 10, 'i', -1, 'fr-PF', 'fr-PF', '153.14'),
        ('fr-PM-x-icu', 11, 10, 'i', -1, 'fr-PM', 'fr-PM', '153.14'),
        ('fr-RE-x-icu', 11, 10, 'i', -1, 'fr-RE', 'fr-RE', '153.14'),
        ('fr-RW-x-icu', 11, 10, 'i', -1, 'fr-RW', 'fr-RW', '153.14'),
        ('fr-SC-x-icu', 11, 10, 'i', -1, 'fr-SC', 'fr-SC', '153.14'),
        ('fr-SN-x-icu', 11, 10, 'i', -1, 'fr-SN', 'fr-SN', '153.14'),
        ('fr-SY-x-icu', 11, 10, 'i', -1, 'fr-SY', 'fr-SY', '153.14'),
        ('fr-TD-x-icu', 11, 10, 'i', -1, 'fr-TD', 'fr-TD', '153.14'),
        ('fr-TG-x-icu', 11, 10, 'i', -1, 'fr-TG', 'fr-TG', '153.14'),
        ('fr-TN-x-icu', 11, 10, 'i', -1, 'fr-TN', 'fr-TN', '153.14'),
        ('fr-VU-x-icu', 11, 10, 'i', -1, 'fr-VU', 'fr-VU', '153.14'),
        ('fr-WF-x-icu', 11, 10, 'i', -1, 'fr-WF', 'fr-WF', '153.14'),
        ('fr-YT-x-icu', 11, 10, 'i', -1, 'fr-YT', 'fr-YT', '153.14'),
        ('fur-x-icu', 11, 10, 'i', -1, 'fur', 'fur', '153.14'),
        ('fur-IT-x-icu', 11, 10, 'i', -1, 'fur-IT', 'fur-IT', '153.14'),
        ('fy-x-icu', 11, 10, 'i', -1, 'fy', 'fy', '153.14'),
        ('fy-NL-x-icu', 11, 10, 'i', -1, 'fy-NL', 'fy-NL', '153.14'),
        ('ga-x-icu', 11, 10, 'i', -1, 'ga', 'ga', '153.14'),
        ('ga-GB-x-icu', 11, 10, 'i', -1, 'ga-GB', 'ga-GB', '153.14'),
        ('ga-IE-x-icu', 11, 10, 'i', -1, 'ga-IE', 'ga-IE', '153.14'),
        ('gd-x-icu', 11, 10, 'i', -1, 'gd', 'gd', '153.14'),
        ('gd-GB-x-icu', 11, 10, 'i', -1, 'gd-GB', 'gd-GB', '153.14'),
        ('gl-x-icu', 11, 10, 'i', -1, 'gl', 'gl', '153.14.37'),
        ('gl-ES-x-icu', 11, 10, 'i', -1, 'gl-ES', 'gl-ES', '153.14.37'),
        ('gsw-x-icu', 11, 10, 'i', -1, 'gsw', 'gsw', '153.14'),
        ('gsw-CH-x-icu', 11, 10, 'i', -1, 'gsw-CH', 'gsw-CH', '153.14'),
        ('gsw-FR-x-icu', 11, 10, 'i', -1, 'gsw-FR', 'gsw-FR', '153.14'),
        ('gsw-LI-x-icu', 11, 10, 'i', -1, 'gsw-LI', 'gsw-LI', '153.14'),
        ('gu-x-icu', 11, 10, 'i', -1, 'gu', 'gu', '153.14.37'),
        ('gu-IN-x-icu', 11, 10, 'i', -1, 'gu-IN', 'gu-IN', '153.14.37'),
        ('guz-x-icu', 11, 10, 'i', -1, 'guz', 'guz', '153.14'),
        ('guz-KE-x-icu', 11, 10, 'i', -1, 'guz-KE', 'guz-KE', '153.14'),
        ('gv-x-icu', 11, 10, 'i', -1, 'gv', 'gv', '153.14'),
        ('gv-IM-x-icu', 11, 10, 'i', -1, 'gv-IM', 'gv-IM', '153.14'),
        ('ha-x-icu', 11, 10, 'i', -1, 'ha', 'ha', '153.14.37'),
        ('ha-GH-x-icu', 11, 10, 'i', -1, 'ha-GH', 'ha-GH', '153.14.37'),
        ('ha-NE-x-icu', 11, 10, 'i', -1, 'ha-NE', 'ha-NE', '153.14.37'),
        ('ha-NG-x-icu', 11, 10, 'i', -1, 'ha-NG', 'ha-NG', '153.14.37'),
        ('haw-x-icu', 11, 10, 'i', -1, 'haw', 'haw', '153.14.37'),
        ('haw-US-x-icu', 11, 10, 'i', -1, 'haw-US', 'haw-US', '153.14.37'),
        ('he-x-icu', 11, 10, 'i', -1, 'he', 'he', '153.14.37'),
        ('he-IL-x-icu', 11, 10, 'i', -1, 'he-IL', 'he-IL', '153.14.37'),
        ('hi-x-icu', 11, 10, 'i', -1, 'hi', 'hi', '153.14.37'),
        ('hi-IN-x-icu', 11, 10, 'i', -1, 'hi-IN', 'hi-IN', '153.14.37'),
        ('hr-x-icu', 11, 10, 'i', -1, 'hr', 'hr', '153.14.37'),
        ('hr-BA-x-icu', 11, 10, 'i', -1, 'hr-BA', 'hr-BA', '153.14.37'),
        ('hr-HR-x-icu', 11, 10, 'i', -1, 'hr-HR', 'hr-HR', '153.14.37'),
        ('hsb-x-icu', 11, 10, 'i', -1, 'hsb', 'hsb', '153.14.37'),
        ('hsb-DE-x-icu', 11, 10, 'i', -1, 'hsb-DE', 'hsb-DE', '153.14.37'),
        ('hu-x-icu', 11, 10, 'i', -1, 'hu', 'hu', '153.14.37'),
        ('hu-HU-x-icu', 11, 10, 'i', -1, 'hu-HU', 'hu-HU', '153.14.37'),
        ('hy-x-icu', 11, 10, 'i', -1, 'hy', 'hy', '153.14.37'),
        ('hy-AM-x-icu', 11, 10, 'i', -1, 'hy-AM', 'hy-AM', '153.14.37'),
        ('ia-x-icu', 11, 10, 'i', -1, 'ia', 'ia', '153.14'),
        ('ia-001-x-icu', 11, 10, 'i', -1, 'ia-001', 'ia-001', '153.14'),
        ('id-x-icu', 11, 10, 'i', -1, 'id', 'id', '153.14'),
        ('id-ID-x-icu', 11, 10, 'i', -1, 'id-ID', 'id-ID', '153.14'),
        ('ig-x-icu', 11, 10, 'i', -1, 'ig', 'ig', '153.14.37'),
        ('ig-NG-x-icu', 11, 10, 'i', -1, 'ig-NG', 'ig-NG', '153.14.37'),
        ('ii-x-icu', 11, 10, 'i', -1, 'ii', 'ii', '153.14'),
        ('ii-CN-x-icu', 11, 10, 'i', -1, 'ii-CN', 'ii-CN', '153.14'),
        ('is-x-icu', 11, 10, 'i', -1, 'is', 'is', '153.14.37'),
        ('is-IS-x-icu', 11, 10, 'i', -1, 'is-IS', 'is-IS', '153.14.37'),
        ('it-x-icu', 11, 10, 'i', -1, 'it', 'it', '153.14'),
        ('it-CH-x-icu', 11, 10, 'i', -1, 'it-CH', 'it-CH', '153.14'),
        ('it-IT-x-icu', 11, 10, 'i', -1, 'it-IT', 'it-IT', '153.14'),
        ('it-SM-x-icu', 11, 10, 'i', -1, 'it-SM', 'it-SM', '153.14'),
        ('it-VA-x-icu', 11, 10, 'i', -1, 'it-VA', 'it-VA', '153.14'),
        ('ja-x-icu', 11, 10, 'i', -1, 'ja', 'ja', '153.14.37'),
        ('ja-JP-x-icu', 11, 10, 'i', -1, 'ja-JP', 'ja-JP', '153.14.37'),
        ('jgo-x-icu', 11, 10, 'i', -1, 'jgo', 'jgo', '153.14'),
        ('jgo-CM-x-icu', 11, 10, 'i', -1, 'jgo-CM', 'jgo-CM', '153.14'),
        ('jmc-x-icu', 11, 10, 'i', -1, 'jmc', 'jmc', '153.14'),
        ('jmc-TZ-x-icu', 11, 10, 'i', -1, 'jmc-TZ', 'jmc-TZ', '153.14'),
        ('jv-x-icu', 11, 10, 'i', -1, 'jv', 'jv', '153.14'),
        ('jv-ID-x-icu', 11, 10, 'i', -1, 'jv-ID', 'jv-ID', '153.14'),
        ('ka-x-icu', 11, 10, 'i', -1, 'ka', 'ka', '153.14.37'),
        ('ka-GE-x-icu', 11, 10, 'i', -1, 'ka-GE', 'ka-GE', '153.14.37'),
        ('kab-x-icu', 11, 10, 'i', -1, 'kab', 'kab', '153.14'),
        ('kab-DZ-x-icu', 11, 10, 'i', -1, 'kab-DZ', 'kab-DZ', '153.14'),
        ('kam-x-icu', 11, 10, 'i', -1, 'kam', 'kam', '153.14'),
        ('kam-KE-x-icu', 11, 10, 'i', -1, 'kam-KE', 'kam-KE', '153.14'),
        ('kde-x-icu', 11, 10, 'i', -1, 'kde', 'kde', '153.14'),
        ('kde-TZ-x-icu', 11, 10, 'i', -1, 'kde-TZ', 'kde-TZ', '153.14'),
        ('kea-x-icu', 11, 10, 'i', -1, 'kea', 'kea', '153.14'),
        ('kea-CV-x-icu', 11, 10, 'i', -1, 'kea-CV', 'kea-CV', '153.14'),
        ('khq-x-icu', 11, 10, 'i', -1, 'khq', 'khq', '153.14'),
        ('khq-ML-x-icu', 11, 10, 'i', -1, 'khq-ML', 'khq-ML', '153.14'),
        ('ki-x-icu', 11, 10, 'i', -1, 'ki', 'ki', '153.14'),
        ('ki-KE-x-icu', 11, 10, 'i', -1, 'ki-KE', 'ki-KE', '153.14'),
        ('kk-x-icu', 11, 10, 'i', -1, 'kk', 'kk', '153.14.37'),
        ('kk-KZ-x-icu', 11, 10, 'i', -1, 'kk-KZ', 'kk-KZ', '153.14.37'),
        ('kkj-x-icu', 11, 10, 'i', -1, 'kkj', 'kkj', '153.14'),
        ('kkj-CM-x-icu', 11, 10, 'i', -1, 'kkj-CM', 'kkj-CM', '153.14'),
        ('kl-x-icu', 11, 10, 'i', -1, 'kl', 'kl', '153.14.37'),
        ('kl-GL-x-icu', 11, 10, 'i', -1, 'kl-GL', 'kl-GL', '153.14.37'),
        ('kln-x-icu', 11, 10, 'i', -1, 'kln', 'kln', '153.14'),
        ('kln-KE-x-icu', 11, 10, 'i', -1, 'kln-KE', 'kln-KE', '153.14'),
        ('km-x-icu', 11, 10, 'i', -1, 'km', 'km', '153.14.37'),
        ('km-KH-x-icu', 11, 10, 'i', -1, 'km-KH', 'km-KH', '153.14.37'),
        ('kn-x-icu', 11, 10, 'i', -1, 'kn', 'kn', '153.14.37'),
        ('kn-IN-x-icu', 11, 10, 'i', -1, 'kn-IN', 'kn-IN', '153.14.37'),
        ('ko-x-icu', 11, 10, 'i', -1, 'ko', 'ko', '153.14.37'),
        ('ko-KP-x-icu', 11, 10, 'i', -1, 'ko-KP', 'ko-KP', '153.14.37'),
        ('ko-KR-x-icu', 11, 10, 'i', -1, 'ko-KR', 'ko-KR', '153.14.37'),
        ('kok-x-icu', 11, 10, 'i', -1, 'kok', 'kok', '153.14.37'),
        ('kok-IN-x-icu', 11, 10, 'i', -1, 'kok-IN', 'kok-IN', '153.14.37'),
        ('ks-x-icu', 11, 10, 'i', -1, 'ks', 'ks', '153.14'),
        ('ks-Arab-x-icu', 11, 10, 'i', -1, 'ks-Arab', 'ks-Arab', '153.14'),
        ('ks-Arab-IN-x-icu', 11, 10, 'i', -1, 'ks-Arab-IN', 'ks-Arab-IN', '153.14'),
        ('ksb-x-icu', 11, 10, 'i', -1, 'ksb', 'ksb', '153.14'),
        ('ksb-TZ-x-icu', 11, 10, 'i', -1, 'ksb-TZ', 'ksb-TZ', '153.14'),
        ('ksf-x-icu', 11, 10, 'i', -1, 'ksf', 'ksf', '153.14'),
        ('ksf-CM-x-icu', 11, 10, 'i', -1, 'ksf-CM', 'ksf-CM', '153.14'),
        ('ksh-x-icu', 11, 10, 'i', -1, 'ksh', 'ksh', '153.14'),
        ('ksh-DE-x-icu', 11, 10, 'i', -1, 'ksh-DE', 'ksh-DE', '153.14'),
        ('ku-x-icu', 11, 10, 'i', -1, 'ku', 'ku', '153.14.37'),
        ('ku-TR-x-icu', 11, 10, 'i', -1, 'ku-TR', 'ku-TR', '153.14.37'),
        ('kw-x-icu', 11, 10, 'i', -1, 'kw', 'kw', '153.14'),
        ('kw-GB-x-icu', 11, 10, 'i', -1, 'kw-GB', 'kw-GB', '153.14'),
        ('ky-x-icu', 11, 10, 'i', -1, 'ky', 'ky', '153.14.37'),
        ('ky-KG-x-icu', 11, 10, 'i', -1, 'ky-KG', 'ky-KG', '153.14.37'),
        ('lag-x-icu', 11, 10, 'i', -1, 'lag', 'lag', '153.14'),
        ('lag-TZ-x-icu', 11, 10, 'i', -1, 'lag-TZ', 'lag-TZ', '153.14'),
        ('lb-x-icu', 11, 10, 'i', -1, 'lb', 'lb', '153.14'),
        ('lb-LU-x-icu', 11, 10, 'i', -1, 'lb-LU', 'lb-LU', '153.14'),
        ('lg-x-icu', 11, 10, 'i', -1, 'lg', 'lg', '153.14'),
        ('lg-UG-x-icu', 11, 10, 'i', -1, 'lg-UG', 'lg-UG', '153.14'),
        ('lkt-x-icu', 11, 10, 'i', -1, 'lkt', 'lkt', '153.14.37'),
        ('lkt-US-x-icu', 11, 10, 'i', -1, 'lkt-US', 'lkt-US', '153.14.37'),
        ('ln-x-icu', 11, 10, 'i', -1, 'ln', 'ln', '153.14.37'),
        ('ln-AO-x-icu', 11, 10, 'i', -1, 'ln-AO', 'ln-AO', '153.14.37'),
        ('ln-CD-x-icu', 11, 10, 'i', -1, 'ln-CD', 'ln-CD', '153.14.37'),
        ('ln-CF-x-icu', 11, 10, 'i', -1, 'ln-CF', 'ln-CF', '153.14.37'),
        ('ln-CG-x-icu', 11, 10, 'i', -1, 'ln-CG', 'ln-CG', '153.14.37'),
        ('lo-x-icu', 11, 10, 'i', -1, 'lo', 'lo', '153.14.37'),
        ('lo-LA-x-icu', 11, 10, 'i', -1, 'lo-LA', 'lo-LA', '153.14.37'),
        ('lrc-x-icu', 11, 10, 'i', -1, 'lrc', 'lrc', '153.14'),
        ('lrc-IQ-x-icu', 11, 10, 'i', -1, 'lrc-IQ', 'lrc-IQ', '153.14'),
        ('lrc-IR-x-icu', 11, 10, 'i', -1, 'lrc-IR', 'lrc-IR', '153.14'),
        ('lt-x-icu', 11, 10, 'i', -1, 'lt', 'lt', '153.14.37'),
        ('lt-LT-x-icu', 11, 10, 'i', -1, 'lt-LT', 'lt-LT', '153.14.37'),
        ('lu-x-icu', 11, 10, 'i', -1, 'lu', 'lu', '153.14'),
        ('lu-CD-x-icu', 11, 10, 'i', -1, 'lu-CD', 'lu-CD', '153.14'),
        ('luo-x-icu', 11, 10, 'i', -1, 'luo', 'luo', '153.14'),
        ('luo-KE-x-icu', 11, 10, 'i', -1, 'luo-KE', 'luo-KE', '153.14'),
        ('luy-x-icu', 11, 10, 'i', -1, 'luy', 'luy', '153.14'),
        ('luy-KE-x-icu', 11, 10, 'i', -1, 'luy-KE', 'luy-KE', '153.14'),
        ('lv-x-icu', 11, 10, 'i', -1, 'lv', 'lv', '153.14.37'),
        ('lv-LV-x-icu', 11, 10, 'i', -1, 'lv-LV', 'lv-LV', '153.14.37'),
        ('mai-x-icu', 11, 10, 'i', -1, 'mai', 'mai', '153.14'),
        ('mai-IN-x-icu', 11, 10, 'i', -1, 'mai-IN', 'mai-IN', '153.14'),
        ('mas-x-icu', 11, 10, 'i', -1, 'mas', 'mas', '153.14'),
        ('mas-KE-x-icu', 11, 10, 'i', -1, 'mas-KE', 'mas-KE', '153.14'),
        ('mas-TZ-x-icu', 11, 10, 'i', -1, 'mas-TZ', 'mas-TZ', '153.14'),
        ('mer-x-icu', 11, 10, 'i', -1, 'mer', 'mer', '153.14'),
        ('mer-KE-x-icu', 11, 10, 'i', -1, 'mer-KE', 'mer-KE', '153.14'),
        ('mfe-x-icu', 11, 10, 'i', -1, 'mfe', 'mfe', '153.14'),
        ('mfe-MU-x-icu', 11, 10, 'i', -1, 'mfe-MU', 'mfe-MU', '153.14'),
        ('mg-x-icu', 11, 10, 'i', -1, 'mg', 'mg', '153.14'),
        ('mg-MG-x-icu', 11, 10, 'i', -1, 'mg-MG', 'mg-MG', '153.14'),
        ('mgh-x-icu', 11, 10, 'i', -1, 'mgh', 'mgh', '153.14'),
        ('mgh-MZ-x-icu', 11, 10, 'i', -1, 'mgh-MZ', 'mgh-MZ', '153.14'),
        ('mgo-x-icu', 11, 10, 'i', -1, 'mgo', 'mgo', '153.14'),
        ('mgo-CM-x-icu', 11, 10, 'i', -1, 'mgo-CM', 'mgo-CM', '153.14'),
        ('mi-x-icu', 11, 10, 'i', -1, 'mi', 'mi', '153.14'),
        ('mi-NZ-x-icu', 11, 10, 'i', -1, 'mi-NZ', 'mi-NZ', '153.14'),
        ('mk-x-icu', 11, 10, 'i', -1, 'mk', 'mk', '153.14.37'),
        ('mk-MK-x-icu', 11, 10, 'i', -1, 'mk-MK', 'mk-MK', '153.14.37'),
        ('ml-x-icu', 11, 10, 'i', -1, 'ml', 'ml', '153.14.37'),
        ('ml-IN-x-icu', 11, 10, 'i', -1, 'ml-IN', 'ml-IN', '153.14.37'),
        ('mn-x-icu', 11, 10, 'i', -1, 'mn', 'mn', '153.14.37'),
        ('mn-MN-x-icu', 11, 10, 'i', -1, 'mn-MN', 'mn-MN', '153.14.37'),
        ('mni-x-icu', 11, 10, 'i', -1, 'mni', 'mni', '153.14'),
        ('mni-Beng-x-icu', 11, 10, 'i', -1, 'mni-Beng', 'mni-Beng', '153.14'),
        ('mni-Beng-IN-x-icu', 11, 10, 'i', -1, 'mni-Beng-IN', 'mni-Beng-IN', '153.14'),
        ('mr-x-icu', 11, 10, 'i', -1, 'mr', 'mr', '153.14.37'),
        ('mr-IN-x-icu', 11, 10, 'i', -1, 'mr-IN', 'mr-IN', '153.14.37'),
        ('ms-x-icu', 11, 10, 'i', -1, 'ms', 'ms', '153.14'),
        ('ms-BN-x-icu', 11, 10, 'i', -1, 'ms-BN', 'ms-BN', '153.14'),
        ('ms-ID-x-icu', 11, 10, 'i', -1, 'ms-ID', 'ms-ID', '153.14'),
        ('ms-MY-x-icu', 11, 10, 'i', -1, 'ms-MY', 'ms-MY', '153.14'),
        ('ms-SG-x-icu', 11, 10, 'i', -1, 'ms-SG', 'ms-SG', '153.14'),
        ('mt-x-icu', 11, 10, 'i', -1, 'mt', 'mt', '153.14.37'),
        ('mt-MT-x-icu', 11, 10, 'i', -1, 'mt-MT', 'mt-MT', '153.14.37'),
        ('mua-x-icu', 11, 10, 'i', -1, 'mua', 'mua', '153.14'),
        ('mua-CM-x-icu', 11, 10, 'i', -1, 'mua-CM', 'mua-CM', '153.14'),
        ('my-x-icu', 11, 10, 'i', -1, 'my', 'my', '153.14.37'),
        ('my-MM-x-icu', 11, 10, 'i', -1, 'my-MM', 'my-MM', '153.14.37'),
        ('mzn-x-icu', 11, 10, 'i', -1, 'mzn', 'mzn', '153.14'),
        ('mzn-IR-x-icu', 11, 10, 'i', -1, 'mzn-IR', 'mzn-IR', '153.14'),
        ('naq-x-icu', 11, 10, 'i', -1, 'naq', 'naq', '153.14'),
        ('naq-NA-x-icu', 11, 10, 'i', -1, 'naq-NA', 'naq-NA', '153.14'),
        ('nb-x-icu', 11, 10, 'i', -1, 'nb', 'nb', '153.14.37'),
        ('nb-NO-x-icu', 11, 10, 'i', -1, 'nb-NO', 'nb-NO', '153.14.37'),
        ('nb-SJ-x-icu', 11, 10, 'i', -1, 'nb-SJ', 'nb-SJ', '153.14.37'),
        ('nd-x-icu', 11, 10, 'i', -1, 'nd', 'nd', '153.14'),
        ('nd-ZW-x-icu', 11, 10, 'i', -1, 'nd-ZW', 'nd-ZW', '153.14'),
        ('nds-x-icu', 11, 10, 'i', -1, 'nds', 'nds', '153.14'),
        ('nds-DE-x-icu', 11, 10, 'i', -1, 'nds-DE', 'nds-DE', '153.14'),
        ('nds-NL-x-icu', 11, 10, 'i', -1, 'nds-NL', 'nds-NL', '153.14'),
        ('ne-x-icu', 11, 10, 'i', -1, 'ne', 'ne', '153.14.37'),
        ('ne-IN-x-icu', 11, 10, 'i', -1, 'ne-IN', 'ne-IN', '153.14.37'),
        ('ne-NP-x-icu', 11, 10, 'i', -1, 'ne-NP', 'ne-NP', '153.14.37'),
        ('nl-x-icu', 11, 10, 'i', -1, 'nl', 'nl', '153.14'),
        ('nl-AW-x-icu', 11, 10, 'i', -1, 'nl-AW', 'nl-AW', '153.14'),
        ('nl-BE-x-icu', 11, 10, 'i', -1, 'nl-BE', 'nl-BE', '153.14'),
        ('nl-BQ-x-icu', 11, 10, 'i', -1, 'nl-BQ', 'nl-BQ', '153.14'),
        ('nl-CW-x-icu', 11, 10, 'i', -1, 'nl-CW', 'nl-CW', '153.14'),
        ('nl-NL-x-icu', 11, 10, 'i', -1, 'nl-NL', 'nl-NL', '153.14'),
        ('nl-SR-x-icu', 11, 10, 'i', -1, 'nl-SR', 'nl-SR', '153.14'),
        ('nl-SX-x-icu', 11, 10, 'i', -1, 'nl-SX', 'nl-SX', '153.14'),
        ('nmg-x-icu', 11, 10, 'i', -1, 'nmg', 'nmg', '153.14'),
        ('nmg-CM-x-icu', 11, 10, 'i', -1, 'nmg-CM', 'nmg-CM', '153.14'),
        ('nn-x-icu', 11, 10, 'i', -1, 'nn', 'nn', '153.14.37'),
        ('nn-NO-x-icu', 11, 10, 'i', -1, 'nn-NO', 'nn-NO', '153.14.37'),
        ('nnh-x-icu', 11, 10, 'i', -1, 'nnh', 'nnh', '153.14'),
        ('nnh-CM-x-icu', 11, 10, 'i', -1, 'nnh-CM', 'nnh-CM', '153.14'),
        ('nus-x-icu', 11, 10, 'i', -1, 'nus', 'nus', '153.14'),
        ('nus-SS-x-icu', 11, 10, 'i', -1, 'nus-SS', 'nus-SS', '153.14'),
        ('nyn-x-icu', 11, 10, 'i', -1, 'nyn', 'nyn', '153.14'),
        ('nyn-UG-x-icu', 11, 10, 'i', -1, 'nyn-UG', 'nyn-UG', '153.14'),
        ('om-x-icu', 11, 10, 'i', -1, 'om', 'om', '153.14.37'),
        ('om-ET-x-icu', 11, 10, 'i', -1, 'om-ET', 'om-ET', '153.14.37'),
        ('om-KE-x-icu', 11, 10, 'i', -1, 'om-KE', 'om-KE', '153.14.37'),
        ('or-x-icu', 11, 10, 'i', -1, 'or', 'or', '153.14.37'),
        ('or-IN-x-icu', 11, 10, 'i', -1, 'or-IN', 'or-IN', '153.14.37'),
        ('os-x-icu', 11, 10, 'i', -1, 'os', 'os', '153.14'),
        ('os-GE-x-icu', 11, 10, 'i', -1, 'os-GE', 'os-GE', '153.14'),
        ('os-RU-x-icu', 11, 10, 'i', -1, 'os-RU', 'os-RU', '153.14'),
        ('pa-x-icu', 11, 10, 'i', -1, 'pa', 'pa', '153.14.37'),
        ('pa-Arab-x-icu', 11, 10, 'i', -1, 'pa-Arab', 'pa-Arab', '153.14.37'),
        ('pa-Arab-PK-x-icu', 11, 10, 'i', -1, 'pa-Arab-PK', 'pa-Arab-PK', '153.14.37'),
        ('pa-Guru-x-icu', 11, 10, 'i', -1, 'pa-Guru', 'pa-Guru', '153.14.37'),
        ('pa-Guru-IN-x-icu', 11, 10, 'i', -1, 'pa-Guru-IN', 'pa-Guru-IN', '153.14.37'),
        ('pcm-x-icu', 11, 10, 'i', -1, 'pcm', 'pcm', '153.14'),
        ('pcm-NG-x-icu', 11, 10, 'i', -1, 'pcm-NG', 'pcm-NG', '153.14'),
        ('pl-x-icu', 11, 10, 'i', -1, 'pl', 'pl', '153.14.37'),
        ('pl-PL-x-icu', 11, 10, 'i', -1, 'pl-PL', 'pl-PL', '153.14.37'),
        ('ps-x-icu', 11, 10, 'i', -1, 'ps', 'ps', '153.14.37'),
        ('ps-AF-x-icu', 11, 10, 'i', -1, 'ps-AF', 'ps-AF', '153.14.37'),
        ('ps-PK-x-icu', 11, 10, 'i', -1, 'ps-PK', 'ps-PK', '153.14.37'),
        ('pt-x-icu', 11, 10, 'i', -1, 'pt', 'pt', '153.14'),
        ('pt-AO-x-icu', 11, 10, 'i', -1, 'pt-AO', 'pt-AO', '153.14'),
        ('pt-BR-x-icu', 11, 10, 'i', -1, 'pt-BR', 'pt-BR', '153.14'),
        ('pt-CH-x-icu', 11, 10, 'i', -1, 'pt-CH', 'pt-CH', '153.14'),
        ('pt-CV-x-icu', 11, 10, 'i', -1, 'pt-CV', 'pt-CV', '153.14'),
        ('pt-GQ-x-icu', 11, 10, 'i', -1, 'pt-GQ', 'pt-GQ', '153.14'),
        ('pt-GW-x-icu', 11, 10, 'i', -1, 'pt-GW', 'pt-GW', '153.14'),
        ('pt-LU-x-icu', 11, 10, 'i', -1, 'pt-LU', 'pt-LU', '153.14'),
        ('pt-MO-x-icu', 11, 10, 'i', -1, 'pt-MO', 'pt-MO', '153.14'),
        ('pt-MZ-x-icu', 11, 10, 'i', -1, 'pt-MZ', 'pt-MZ', '153.14'),
        ('pt-PT-x-icu', 11, 10, 'i', -1, 'pt-PT', 'pt-PT', '153.14'),
        ('pt-ST-x-icu', 11, 10, 'i', -1, 'pt-ST', 'pt-ST', '153.14'),
        ('pt-TL-x-icu', 11, 10, 'i', -1, 'pt-TL', 'pt-TL', '153.14'),
        ('qu-x-icu', 11, 10, 'i', -1, 'qu', 'qu', '153.14'),
        ('qu-BO-x-icu', 11, 10, 'i', -1, 'qu-BO', 'qu-BO', '153.14'),
        ('qu-EC-x-icu', 11, 10, 'i', -1, 'qu-EC', 'qu-EC', '153.14'),
        ('qu-PE-x-icu', 11, 10, 'i', -1, 'qu-PE', 'qu-PE', '153.14'),
        ('rm-x-icu', 11, 10, 'i', -1, 'rm', 'rm', '153.14'),
        ('rm-CH-x-icu', 11, 10, 'i', -1, 'rm-CH', 'rm-CH', '153.14'),
        ('rn-x-icu', 11, 10, 'i', -1, 'rn', 'rn', '153.14'),
        ('rn-BI-x-icu', 11, 10, 'i', -1, 'rn-BI', 'rn-BI', '153.14'),
        ('ro-x-icu', 11, 10, 'i', -1, 'ro', 'ro', '153.14.37'),
        ('ro-MD-x-icu', 11, 10, 'i', -1, 'ro-MD', 'ro-MD', '153.14.37'),
        ('ro-RO-x-icu', 11, 10, 'i', -1, 'ro-RO', 'ro-RO', '153.14.37'),
        ('rof-x-icu', 11, 10, 'i', -1, 'rof', 'rof', '153.14'),
        ('rof-TZ-x-icu', 11, 10, 'i', -1, 'rof-TZ', 'rof-TZ', '153.14'),
        ('ru-x-icu', 11, 10, 'i', -1, 'ru', 'ru', '153.14.37'),
        ('ru-BY-x-icu', 11, 10, 'i', -1, 'ru-BY', 'ru-BY', '153.14.37'),
        ('ru-KG-x-icu', 11, 10, 'i', -1, 'ru-KG', 'ru-KG', '153.14.37'),
        ('ru-KZ-x-icu', 11, 10, 'i', -1, 'ru-KZ', 'ru-KZ', '153.14.37'),
        ('ru-MD-x-icu', 11, 10, 'i', -1, 'ru-MD', 'ru-MD', '153.14.37'),
        ('ru-RU-x-icu', 11, 10, 'i', -1, 'ru-RU', 'ru-RU', '153.14.37'),
        ('ru-UA-x-icu', 11, 10, 'i', -1, 'ru-UA', 'ru-UA', '153.14.37'),
        ('rw-x-icu', 11, 10, 'i', -1, 'rw', 'rw', '153.14'),
        ('rw-RW-x-icu', 11, 10, 'i', -1, 'rw-RW', 'rw-RW', '153.14'),
        ('rwk-x-icu', 11, 10, 'i', -1, 'rwk', 'rwk', '153.14'),
        ('rwk-TZ-x-icu', 11, 10, 'i', -1, 'rwk-TZ', 'rwk-TZ', '153.14'),
        ('sah-x-icu', 11, 10, 'i', -1, 'sah', 'sah', '153.14'),
        ('sah-RU-x-icu', 11, 10, 'i', -1, 'sah-RU', 'sah-RU', '153.14'),
        ('saq-x-icu', 11, 10, 'i', -1, 'saq', 'saq', '153.14'),
        ('saq-KE-x-icu', 11, 10, 'i', -1, 'saq-KE', 'saq-KE', '153.14'),
        ('sat-x-icu', 11, 10, 'i', -1, 'sat', 'sat', '153.14'),
        ('sat-Olck-x-icu', 11, 10, 'i', -1, 'sat-Olck', 'sat-Olck', '153.14'),
        ('sat-Olck-IN-x-icu', 11, 10, 'i', -1, 'sat-Olck-IN', 'sat-Olck-IN', '153.14'),
        ('sbp-x-icu', 11, 10, 'i', -1, 'sbp', 'sbp', '153.14'),
        ('sbp-TZ-x-icu', 11, 10, 'i', -1, 'sbp-TZ', 'sbp-TZ', '153.14'),
        ('sd-x-icu', 11, 10, 'i', -1, 'sd', 'sd', '153.14'),
        ('sd-Arab-x-icu', 11, 10, 'i', -1, 'sd-Arab', 'sd-Arab', '153.14'),
        ('sd-Arab-PK-x-icu', 11, 10, 'i', -1, 'sd-Arab-PK', 'sd-Arab-PK', '153.14'),
        ('sd-Deva-x-icu', 11, 10, 'i', -1, 'sd-Deva', 'sd-Deva', '153.14'),
        ('sd-Deva-IN-x-icu', 11, 10, 'i', -1, 'sd-Deva-IN', 'sd-Deva-IN', '153.14'),
        ('se-x-icu', 11, 10, 'i', -1, 'se', 'se', '153.14.37'),
        ('se-FI-x-icu', 11, 10, 'i', -1, 'se-FI', 'se-FI', '153.14.37'),
        ('se-NO-x-icu', 11, 10, 'i', -1, 'se-NO', 'se-NO', '153.14.37'),
        ('se-SE-x-icu', 11, 10, 'i', -1, 'se-SE', 'se-SE', '153.14.37'),
        ('seh-x-icu', 11, 10, 'i', -1, 'seh', 'seh', '153.14'),
        ('seh-MZ-x-icu', 11, 10, 'i', -1, 'seh-MZ', 'seh-MZ', '153.14'),
        ('ses-x-icu', 11, 10, 'i', -1, 'ses', 'ses', '153.14'),
        ('ses-ML-x-icu', 11, 10, 'i', -1, 'ses-ML', 'ses-ML', '153.14'),
        ('sg-x-icu', 11, 10, 'i', -1, 'sg', 'sg', '153.14'),
        ('sg-CF-x-icu', 11, 10, 'i', -1, 'sg-CF', 'sg-CF', '153.14'),
        ('shi-x-icu', 11, 10, 'i', -1, 'shi', 'shi', '153.14'),
        ('shi-Latn-x-icu', 11, 10, 'i', -1, 'shi-Latn', 'shi-Latn', '153.14'),
        ('shi-Latn-MA-x-icu', 11, 10, 'i', -1, 'shi-Latn-MA', 'shi-Latn-MA', '153.14'),
        ('shi-Tfng-x-icu', 11, 10, 'i', -1, 'shi-Tfng', 'shi-Tfng', '153.14'),
        ('shi-Tfng-MA-x-icu', 11, 10, 'i', -1, 'shi-Tfng-MA', 'shi-Tfng-MA', '153.14'),
        ('si-x-icu', 11, 10, 'i', -1, 'si', 'si', '153.14.37'),
        ('si-LK-x-icu', 11, 10, 'i', -1, 'si-LK', 'si-LK', '153.14.37'),
        ('sk-x-icu', 11, 10, 'i', -1, 'sk', 'sk', '153.14.37'),
        ('sk-SK-x-icu', 11, 10, 'i', -1, 'sk-SK', 'sk-SK', '153.14.37'),
        ('sl-x-icu', 11, 10, 'i', -1, 'sl', 'sl', '153.14.37'),
        ('sl-SI-x-icu', 11, 10, 'i', -1, 'sl-SI', 'sl-SI', '153.14.37'),
        ('smn-x-icu', 11, 10, 'i', -1, 'smn', 'smn', '153.14.37'),
        ('smn-FI-x-icu', 11, 10, 'i', -1, 'smn-FI', 'smn-FI', '153.14.37'),
        ('sn-x-icu', 11, 10, 'i', -1, 'sn', 'sn', '153.14'),
        ('sn-ZW-x-icu', 11, 10, 'i', -1, 'sn-ZW', 'sn-ZW', '153.14'),
        ('so-x-icu', 11, 10, 'i', -1, 'so', 'so', '153.14'),
        ('so-DJ-x-icu', 11, 10, 'i', -1, 'so-DJ', 'so-DJ', '153.14'),
        ('so-ET-x-icu', 11, 10, 'i', -1, 'so-ET', 'so-ET', '153.14'),
        ('so-KE-x-icu', 11, 10, 'i', -1, 'so-KE', 'so-KE', '153.14'),
        ('so-SO-x-icu', 11, 10, 'i', -1, 'so-SO', 'so-SO', '153.14'),
        ('sq-x-icu', 11, 10, 'i', -1, 'sq', 'sq', '153.14.37'),
        ('sq-AL-x-icu', 11, 10, 'i', -1, 'sq-AL', 'sq-AL', '153.14.37'),
        ('sq-MK-x-icu', 11, 10, 'i', -1, 'sq-MK', 'sq-MK', '153.14.37'),
        ('sq-XK-x-icu', 11, 10, 'i', -1, 'sq-XK', 'sq-XK', '153.14.37'),
        ('sr-x-icu', 11, 10, 'i', -1, 'sr', 'sr', '153.14.37'),
        ('sr-Cyrl-x-icu', 11, 10, 'i', -1, 'sr-Cyrl', 'sr-Cyrl', '153.14.37'),
        ('sr-Cyrl-BA-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-BA', 'sr-Cyrl-BA', '153.14.37'),
        ('sr-Cyrl-ME-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-ME', 'sr-Cyrl-ME', '153.14.37'),
        ('sr-Cyrl-RS-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-RS', 'sr-Cyrl-RS', '153.14.37'),
        ('sr-Cyrl-XK-x-icu', 11, 10, 'i', -1, 'sr-Cyrl-XK', 'sr-Cyrl-XK', '153.14.37'),
        ('sr-Latn-x-icu', 11, 10, 'i', -1, 'sr-Latn', 'sr-Latn', '153.14.37'),
        ('sr-Latn-BA-x-icu', 11, 10, 'i', -1, 'sr-Latn-BA', 'sr-Latn-BA', '153.14.37'),
        ('sr-Latn-ME-x-icu', 11, 10, 'i', -1, 'sr-Latn-ME', 'sr-Latn-ME', '153.14.37'),
        ('sr-Latn-RS-x-icu', 11, 10, 'i', -1, 'sr-Latn-RS', 'sr-Latn-RS', '153.14.37'),
        ('sr-Latn-XK-x-icu', 11, 10, 'i', -1, 'sr-Latn-XK', 'sr-Latn-XK', '153.14.37'),
        ('su-x-icu', 11, 10, 'i', -1, 'su', 'su', '153.14'),
        ('su-Latn-x-icu', 11, 10, 'i', -1, 'su-Latn', 'su-Latn', '153.14'),
        ('su-Latn-ID-x-icu', 11, 10, 'i', -1, 'su-Latn-ID', 'su-Latn-ID', '153.14'),
        ('sv-x-icu', 11, 10, 'i', -1, 'sv', 'sv', '153.14.37'),
        ('sv-AX-x-icu', 11, 10, 'i', -1, 'sv-AX', 'sv-AX', '153.14.37'),
        ('sv-FI-x-icu', 11, 10, 'i', -1, 'sv-FI', 'sv-FI', '153.14.37'),
        ('sv-SE-x-icu', 11, 10, 'i', -1, 'sv-SE', 'sv-SE', '153.14.37'),
        ('sw-x-icu', 11, 10, 'i', -1, 'sw', 'sw', '153.14'),
        ('sw-CD-x-icu', 11, 10, 'i', -1, 'sw-CD', 'sw-CD', '153.14'),
        ('sw-KE-x-icu', 11, 10, 'i', -1, 'sw-KE', 'sw-KE', '153.14'),
        ('sw-TZ-x-icu', 11, 10, 'i', -1, 'sw-TZ', 'sw-TZ', '153.14'),
        ('sw-UG-x-icu', 11, 10, 'i', -1, 'sw-UG', 'sw-UG', '153.14'),
        ('ta-x-icu', 11, 10, 'i', -1, 'ta', 'ta', '153.14.37'),
        ('ta-IN-x-icu', 11, 10, 'i', -1, 'ta-IN', 'ta-IN', '153.14.37'),
        ('ta-LK-x-icu', 11, 10, 'i', -1, 'ta-LK', 'ta-LK', '153.14.37'),
        ('ta-MY-x-icu', 11, 10, 'i', -1, 'ta-MY', 'ta-MY', '153.14.37'),
        ('ta-SG-x-icu', 11, 10, 'i', -1, 'ta-SG', 'ta-SG', '153.14.37'),
        ('te-x-icu', 11, 10, 'i', -1, 'te', 'te', '153.14.37'),
        ('te-IN-x-icu', 11, 10, 'i', -1, 'te-IN', 'te-IN', '153.14.37'),
        ('teo-x-icu', 11, 10, 'i', -1, 'teo', 'teo', '153.14'),
        ('teo-KE-x-icu', 11, 10, 'i', -1, 'teo-KE', 'teo-KE', '153.14'),
        ('teo-UG-x-icu', 11, 10, 'i', -1, 'teo-UG', 'teo-UG', '153.14'),
        ('tg-x-icu', 11, 10, 'i', -1, 'tg', 'tg', '153.14'),
        ('tg-TJ-x-icu', 11, 10, 'i', -1, 'tg-TJ', 'tg-TJ', '153.14'),
        ('th-x-icu', 11, 10, 'i', -1, 'th', 'th', '153.14.37'),
        ('th-TH-x-icu', 11, 10, 'i', -1, 'th-TH', 'th-TH', '153.14.37'),
        ('ti-x-icu', 11, 10, 'i', -1, 'ti', 'ti', '153.14'),
        ('ti-ER-x-icu', 11, 10, 'i', -1, 'ti-ER', 'ti-ER', '153.14'),
        ('ti-ET-x-icu', 11, 10, 'i', -1, 'ti-ET', 'ti-ET', '153.14'),
        ('tk-x-icu', 11, 10, 'i', -1, 'tk', 'tk', '153.14.37'),
        ('tk-TM-x-icu', 11, 10, 'i', -1, 'tk-TM', 'tk-TM', '153.14.37'),
        ('to-x-icu', 11, 10, 'i', -1, 'to', 'to', '153.14.37'),
        ('to-TO-x-icu', 11, 10, 'i', -1, 'to-TO', 'to-TO', '153.14.37'),
        ('tr-x-icu', 11, 10, 'i', -1, 'tr', 'tr', '153.14.37'),
        ('tr-CY-x-icu', 11, 10, 'i', -1, 'tr-CY', 'tr-CY', '153.14.37'),
        ('tr-TR-x-icu', 11, 10, 'i', -1, 'tr-TR', 'tr-TR', '153.14.37'),
        ('tt-x-icu', 11, 10, 'i', -1, 'tt', 'tt', '153.14'),
        ('tt-RU-x-icu', 11, 10, 'i', -1, 'tt-RU', 'tt-RU', '153.14'),
        ('twq-x-icu', 11, 10, 'i', -1, 'twq', 'twq', '153.14'),
        ('twq-NE-x-icu', 11, 10, 'i', -1, 'twq-NE', 'twq-NE', '153.14'),
        ('tzm-x-icu', 11, 10, 'i', -1, 'tzm', 'tzm', '153.14'),
        ('tzm-MA-x-icu', 11, 10, 'i', -1, 'tzm-MA', 'tzm-MA', '153.14'),
        ('ug-x-icu', 11, 10, 'i', -1, 'ug', 'ug', '153.14.37'),
        ('ug-CN-x-icu', 11, 10, 'i', -1, 'ug-CN', 'ug-CN', '153.14.37'),
        ('uk-x-icu', 11, 10, 'i', -1, 'uk', 'uk', '153.14.37'),
        ('uk-UA-x-icu', 11, 10, 'i', -1, 'uk-UA', 'uk-UA', '153.14.37'),
        ('ur-x-icu', 11, 10, 'i', -1, 'ur', 'ur', '153.14.37'),
        ('ur-IN-x-icu', 11, 10, 'i', -1, 'ur-IN', 'ur-IN', '153.14.37'),
        ('ur-PK-x-icu', 11, 10, 'i', -1, 'ur-PK', 'ur-PK', '153.14.37'),
        ('uz-x-icu', 11, 10, 'i', -1, 'uz', 'uz', '153.14.37'),
        ('uz-Arab-x-icu', 11, 10, 'i', -1, 'uz-Arab', 'uz-Arab', '153.14.37'),
        ('uz-Arab-AF-x-icu', 11, 10, 'i', -1, 'uz-Arab-AF', 'uz-Arab-AF', '153.14.37'),
        ('uz-Cyrl-x-icu', 11, 10, 'i', -1, 'uz-Cyrl', 'uz-Cyrl', '153.14.37'),
        ('uz-Cyrl-UZ-x-icu', 11, 10, 'i', -1, 'uz-Cyrl-UZ', 'uz-Cyrl-UZ', '153.14.37'),
        ('uz-Latn-x-icu', 11, 10, 'i', -1, 'uz-Latn', 'uz-Latn', '153.14.37'),
        ('uz-Latn-UZ-x-icu', 11, 10, 'i', -1, 'uz-Latn-UZ', 'uz-Latn-UZ', '153.14.37'),
        ('vai-x-icu', 11, 10, 'i', -1, 'vai', 'vai', '153.14'),
        ('vai-Latn-x-icu', 11, 10, 'i', -1, 'vai-Latn', 'vai-Latn', '153.14'),
        ('vai-Latn-LR-x-icu', 11, 10, 'i', -1, 'vai-Latn-LR', 'vai-Latn-LR', '153.14'),
        ('vai-Vaii-x-icu', 11, 10, 'i', -1, 'vai-Vaii', 'vai-Vaii', '153.14'),
        ('vai-Vaii-LR-x-icu', 11, 10, 'i', -1, 'vai-Vaii-LR', 'vai-Vaii-LR', '153.14'),
        ('vi-x-icu', 11, 10, 'i', -1, 'vi', 'vi', '153.14.37'),
        ('vi-VN-x-icu', 11, 10, 'i', -1, 'vi-VN', 'vi-VN', '153.14.37'),
        ('vun-x-icu', 11, 10, 'i', -1, 'vun', 'vun', '153.14'),
        ('vun-TZ-x-icu', 11, 10, 'i', -1, 'vun-TZ', 'vun-TZ', '153.14'),
        ('wae-x-icu', 11, 10, 'i', -1, 'wae', 'wae', '153.14'),
        ('wae-CH-x-icu', 11, 10, 'i', -1, 'wae-CH', 'wae-CH', '153.14'),
        ('wo-x-icu', 11, 10, 'i', -1, 'wo', 'wo', '153.14.37'),
        ('wo-SN-x-icu', 11, 10, 'i', -1, 'wo-SN', 'wo-SN', '153.14.37'),
        ('xh-x-icu', 11, 10, 'i', -1, 'xh', 'xh', '153.14'),
        ('xh-ZA-x-icu', 11, 10, 'i', -1, 'xh-ZA', 'xh-ZA', '153.14'),
        ('xog-x-icu', 11, 10, 'i', -1, 'xog', 'xog', '153.14'),
        ('xog-UG-x-icu', 11, 10, 'i', -1, 'xog-UG', 'xog-UG', '153.14'),
        ('yav-x-icu', 11, 10, 'i', -1, 'yav', 'yav', '153.14'),
        ('yav-CM-x-icu', 11, 10, 'i', -1, 'yav-CM', 'yav-CM', '153.14'),
        ('yi-x-icu', 11, 10, 'i', -1, 'yi', 'yi', '153.14.37'),
        ('yi-001-x-icu', 11, 10, 'i', -1, 'yi-001', 'yi-001', '153.14.37'),
        ('yo-x-icu', 11, 10, 'i', -1, 'yo', 'yo', '153.14.37'),
        ('yo-BJ-x-icu', 11, 10, 'i', -1, 'yo-BJ', 'yo-BJ', '153.14.37'),
        ('yo-NG-x-icu', 11, 10, 'i', -1, 'yo-NG', 'yo-NG', '153.14.37'),
        ('yue-x-icu', 11, 10, 'i', -1, 'yue', 'yue', '153.14.37'),
        ('yue-Hans-x-icu', 11, 10, 'i', -1, 'yue-Hans', 'yue-Hans', '153.14.37'),
        ('yue-Hans-CN-x-icu', 11, 10, 'i', -1, 'yue-Hans-CN', 'yue-Hans-CN', '153.14.37'),
        ('yue-Hant-x-icu', 11, 10, 'i', -1, 'yue-Hant', 'yue-Hant', '153.14.37'),
        ('yue-Hant-HK-x-icu', 11, 10, 'i', -1, 'yue-Hant-HK', 'yue-Hant-HK', '153.14.37'),
        ('zgh-x-icu', 11, 10, 'i', -1, 'zgh', 'zgh', '153.14'),
        ('zgh-MA-x-icu', 11, 10, 'i', -1, 'zgh-MA', 'zgh-MA', '153.14'),
        ('zh-x-icu', 11, 10, 'i', -1, 'zh', 'zh', '153.14.37'),
        ('zh-Hans-x-icu', 11, 10, 'i', -1, 'zh-Hans', 'zh-Hans', '153.14.37'),
        ('zh-Hans-CN-x-icu', 11, 10, 'i', -1, 'zh-Hans-CN', 'zh-Hans-CN', '153.14.37'),
        ('zh-Hans-HK-x-icu', 11, 10, 'i', -1, 'zh-Hans-HK', 'zh-Hans-HK', '153.14.37'),
        ('zh-Hans-MO-x-icu', 11, 10, 'i', -1, 'zh-Hans-MO', 'zh-Hans-MO', '153.14.37'),
        ('zh-Hans-SG-x-icu', 11, 10, 'i', -1, 'zh-Hans-SG', 'zh-Hans-SG', '153.14.37'),
        ('zh-Hant-x-icu', 11, 10, 'i', -1, 'zh-Hant', 'zh-Hant', '153.14.37'),
        ('zh-Hant-HK-x-icu', 11, 10, 'i', -1, 'zh-Hant-HK', 'zh-Hant-HK', '153.14.37'),
        ('zh-Hant-MO-x-icu', 11, 10, 'i', -1, 'zh-Hant-MO', 'zh-Hant-MO', '153.14.37'),
        ('zh-Hant-TW-x-icu', 11, 10, 'i', -1, 'zh-Hant-TW', 'zh-Hant-TW', '153.14.37'),
        ('zu-x-icu', 11, 10, 'i', -1, 'zu', 'zu', '153.14'),
        ('zu-ZA-x-icu', 11, 10, 'i', -1, 'zu-ZA', 'zu-ZA', '153.14')
      RETURNING oid
    ), tmp_descr (row_number, description) AS (
      -- Some collations do not have a matching description. We need to correctly match
      -- a collation with its corresponding description. Use row_number to track the collation
      -- list order.
      VALUES
        (3, 'Unknown language'),
        (4, 'Afrikaans'),
        (5, 'Afrikaans (Namibia)'),
        (6, 'Afrikaans (South Africa)'),
        (7, 'Aghem'),
        (8, 'Aghem (Cameroon)'),
        (9, 'Akan'),
        (10, 'Akan (Ghana)'),
        (11, 'Amharic'),
        (12, 'Amharic (Ethiopia)'),
        (13, 'Arabic'),
        (14, 'Arabic (World)'),
        (15, 'Arabic (United Arab Emirates)'),
        (16, 'Arabic (Bahrain)'),
        (17, 'Arabic (Djibouti)'),
        (18, 'Arabic (Algeria)'),
        (19, 'Arabic (Egypt)'),
        (20, 'Arabic (Western Sahara)'),
        (21, 'Arabic (Eritrea)'),
        (22, 'Arabic (Israel)'),
        (23, 'Arabic (Iraq)'),
        (24, 'Arabic (Jordan)'),
        (25, 'Arabic (Comoros)'),
        (26, 'Arabic (Kuwait)'),
        (27, 'Arabic (Lebanon)'),
        (28, 'Arabic (Libya)'),
        (29, 'Arabic (Morocco)'),
        (30, 'Arabic (Mauritania)'),
        (31, 'Arabic (Oman)'),
        (32, 'Arabic (Palestinian Territories)'),
        (33, 'Arabic (Qatar)'),
        (34, 'Arabic (Saudi Arabia)'),
        (35, 'Arabic (Sudan)'),
        (36, 'Arabic (Somalia)'),
        (37, 'Arabic (South Sudan)'),
        (38, 'Arabic (Syria)'),
        (39, 'Arabic (Chad)'),
        (40, 'Arabic (Tunisia)'),
        (41, 'Arabic (Yemen)'),
        (42, 'Assamese'),
        (43, 'Assamese (India)'),
        (44, 'Asu'),
        (45, 'Asu (Tanzania)'),
        (46, 'Asturian'),
        (47, 'Asturian (Spain)'),
        (48, 'Azerbaijani'),
        (49, 'Azerbaijani (Cyrillic)'),
        (50, 'Azerbaijani (Cyrillic, Azerbaijan)'),
        (51, 'Azerbaijani (Latin)'),
        (52, 'Azerbaijani (Latin, Azerbaijan)'),
        (53, 'Basaa'),
        (54, 'Basaa (Cameroon)'),
        (55, 'Belarusian'),
        (56, 'Belarusian (Belarus)'),
        (57, 'Bemba'),
        (58, 'Bemba (Zambia)'),
        (59, 'Bena'),
        (60, 'Bena (Tanzania)'),
        (61, 'Bulgarian'),
        (62, 'Bulgarian (Bulgaria)'),
        (63, 'Bambara'),
        (64, 'Bambara (Mali)'),
        (65, 'Bangla'),
        (66, 'Bangla (Bangladesh)'),
        (67, 'Bangla (India)'),
        (68, 'Tibetan'),
        (69, 'Tibetan (China)'),
        (70, 'Tibetan (India)'),
        (71, 'Breton'),
        (72, 'Breton (France)'),
        (73, 'Bodo'),
        (74, 'Bodo (India)'),
        (75, 'Bosnian'),
        (76, 'Bosnian (Cyrillic)'),
        (77, 'Bosnian (Cyrillic, Bosnia & Herzegovina)'),
        (78, 'Bosnian (Latin)'),
        (79, 'Bosnian (Latin, Bosnia & Herzegovina)'),
        (80, 'Catalan'),
        (81, 'Catalan (Andorra)'),
        (82, 'Catalan (Spain)'),
        (83, 'Catalan (France)'),
        (84, 'Catalan (Italy)'),
        (85, 'Chakma'),
        (86, 'Chakma (Bangladesh)'),
        (87, 'Chakma (India)'),
        (88, 'Chechen'),
        (89, 'Chechen (Russia)'),
        (90, 'Cebuano'),
        (91, 'Cebuano (Philippines)'),
        (92, 'Chiga'),
        (93, 'Chiga (Uganda)'),
        (94, 'Cherokee'),
        (95, 'Cherokee (United States)'),
        (96, 'Central Kurdish'),
        (97, 'Central Kurdish (Iraq)'),
        (98, 'Central Kurdish (Iran)'),
        (99, 'Czech'),
        (100, 'Czech (Czechia)'),
        (101, 'Welsh'),
        (102, 'Welsh (United Kingdom)'),
        (103, 'Danish'),
        (104, 'Danish (Denmark)'),
        (105, 'Danish (Greenland)'),
        (106, 'Taita'),
        (107, 'Taita (Kenya)'),
        (108, 'German'),
        (109, 'German (Austria)'),
        (110, 'German (Belgium)'),
        (111, 'German (Switzerland)'),
        (112, 'German (Germany)'),
        (113, 'German (Italy)'),
        (114, 'German (Liechtenstein)'),
        (115, 'German (Luxembourg)'),
        (116, 'Zarma'),
        (117, 'Zarma (Niger)'),
        (118, 'Lower Sorbian'),
        (119, 'Lower Sorbian (Germany)'),
        (120, 'Duala'),
        (121, 'Duala (Cameroon)'),
        (122, 'Jola-Fonyi'),
        (123, 'Jola-Fonyi (Senegal)'),
        (124, 'Dzongkha'),
        (125, 'Dzongkha (Bhutan)'),
        (126, 'Embu'),
        (127, 'Embu (Kenya)'),
        (128, 'Ewe'),
        (129, 'Ewe (Ghana)'),
        (130, 'Ewe (Togo)'),
        (131, 'Greek'),
        (132, 'Greek (Cyprus)'),
        (133, 'Greek (Greece)'),
        (134, 'English'),
        (135, 'English (World)'),
        (136, 'English (Europe)'),
        (137, 'English (United Arab Emirates)'),
        (138, 'English (Antigua & Barbuda)'),
        (139, 'English (Anguilla)'),
        (140, 'English (American Samoa)'),
        (141, 'English (Austria)'),
        (142, 'English (Australia)'),
        (143, 'English (Barbados)'),
        (144, 'English (Belgium)'),
        (145, 'English (Burundi)'),
        (146, 'English (Bermuda)'),
        (147, 'English (Bahamas)'),
        (148, 'English (Botswana)'),
        (149, 'English (Belize)'),
        (150, 'English (Canada)'),
        (151, 'English (Cocos [Keeling] Islands)'),
        (152, 'English (Switzerland)'),
        (153, 'English (Cook Islands)'),
        (154, 'English (Cameroon)'),
        (155, 'English (Christmas Island)'),
        (156, 'English (Cyprus)'),
        (157, 'English (Germany)'),
        (158, 'English (Diego Garcia)'),
        (159, 'English (Denmark)'),
        (160, 'English (Dominica)'),
        (161, 'English (Eritrea)'),
        (162, 'English (Finland)'),
        (163, 'English (Fiji)'),
        (164, 'English (Falkland Islands)'),
        (165, 'English (Micronesia)'),
        (166, 'English (United Kingdom)'),
        (167, 'English (Grenada)'),
        (168, 'English (Guernsey)'),
        (169, 'English (Ghana)'),
        (170, 'English (Gibraltar)'),
        (171, 'English (Gambia)'),
        (172, 'English (Guam)'),
        (173, 'English (Guyana)'),
        (174, 'English (Hong Kong SAR China)'),
        (175, 'English (Ireland)'),
        (176, 'English (Israel)'),
        (177, 'English (Isle of Man)'),
        (178, 'English (India)'),
        (179, 'English (British Indian Ocean Territory)'),
        (180, 'English (Jersey)'),
        (181, 'English (Jamaica)'),
        (182, 'English (Kenya)'),
        (183, 'English (Kiribati)'),
        (184, 'English (St. Kitts & Nevis)'),
        (185, 'English (Cayman Islands)'),
        (186, 'English (St. Lucia)'),
        (187, 'English (Liberia)'),
        (188, 'English (Lesotho)'),
        (189, 'English (Madagascar)'),
        (190, 'English (Marshall Islands)'),
        (191, 'English (Macao SAR China)'),
        (192, 'English (Northern Mariana Islands)'),
        (193, 'English (Montserrat)'),
        (194, 'English (Malta)'),
        (195, 'English (Mauritius)'),
        (196, 'English (Malawi)'),
        (197, 'English (Malaysia)'),
        (198, 'English (Namibia)'),
        (199, 'English (Norfolk Island)'),
        (200, 'English (Nigeria)'),
        (201, 'English (Netherlands)'),
        (202, 'English (Nauru)'),
        (203, 'English (Niue)'),
        (204, 'English (New Zealand)'),
        (205, 'English (Papua New Guinea)'),
        (206, 'English (Philippines)'),
        (207, 'English (Pakistan)'),
        (208, 'English (Pitcairn Islands)'),
        (209, 'English (Puerto Rico)'),
        (210, 'English (Palau)'),
        (211, 'English (Rwanda)'),
        (212, 'English (Solomon Islands)'),
        (213, 'English (Seychelles)'),
        (214, 'English (Sudan)'),
        (215, 'English (Sweden)'),
        (216, 'English (Singapore)'),
        (217, 'English (St. Helena)'),
        (218, 'English (Slovenia)'),
        (219, 'English (Sierra Leone)'),
        (220, 'English (South Sudan)'),
        (221, 'English (Sint Maarten)'),
        (222, 'English (Eswatini)'),
        (223, 'English (Turks & Caicos Islands)'),
        (224, 'English (Tokelau)'),
        (225, 'English (Tonga)'),
        (226, 'English (Trinidad & Tobago)'),
        (227, 'English (Tuvalu)'),
        (228, 'English (Tanzania)'),
        (229, 'English (Uganda)'),
        (230, 'English (U.S. Outlying Islands)'),
        (231, 'English (United States)'),
        (232, 'English (United States, Computer)'),
        (233, 'English (St. Vincent & Grenadines)'),
        (234, 'English (British Virgin Islands)'),
        (235, 'English (U.S. Virgin Islands)'),
        (236, 'English (Vanuatu)'),
        (237, 'English (Samoa)'),
        (238, 'English (South Africa)'),
        (239, 'English (Zambia)'),
        (240, 'English (Zimbabwe)'),
        (241, 'Esperanto'),
        (242, 'Esperanto (World)'),
        (243, 'Spanish'),
        (244, 'Spanish (Latin America)'),
        (245, 'Spanish (Argentina)'),
        (246, 'Spanish (Bolivia)'),
        (247, 'Spanish (Brazil)'),
        (248, 'Spanish (Belize)'),
        (249, 'Spanish (Chile)'),
        (250, 'Spanish (Colombia)'),
        (251, 'Spanish (Costa Rica)'),
        (252, 'Spanish (Cuba)'),
        (253, 'Spanish (Dominican Republic)'),
        (254, 'Spanish (Ceuta & Melilla)'),
        (255, 'Spanish (Ecuador)'),
        (256, 'Spanish (Spain)'),
        (257, 'Spanish (Equatorial Guinea)'),
        (258, 'Spanish (Guatemala)'),
        (259, 'Spanish (Honduras)'),
        (260, 'Spanish (Canary Islands)'),
        (261, 'Spanish (Mexico)'),
        (262, 'Spanish (Nicaragua)'),
        (263, 'Spanish (Panama)'),
        (264, 'Spanish (Peru)'),
        (265, 'Spanish (Philippines)'),
        (266, 'Spanish (Puerto Rico)'),
        (267, 'Spanish (Paraguay)'),
        (268, 'Spanish (El Salvador)'),
        (269, 'Spanish (United States)'),
        (270, 'Spanish (Uruguay)'),
        (271, 'Spanish (Venezuela)'),
        (272, 'Estonian'),
        (273, 'Estonian (Estonia)'),
        (274, 'Basque'),
        (275, 'Basque (Spain)'),
        (276, 'Ewondo'),
        (277, 'Ewondo (Cameroon)'),
        (278, 'Persian'),
        (279, 'Persian (Afghanistan)'),
        (280, 'Persian (Iran)'),
        (281, 'Fulah'),
        (282, 'Fulah (Adlam)'),
        (283, 'Fulah (Adlam, Burkina Faso)'),
        (284, 'Fulah (Adlam, Cameroon)'),
        (285, 'Fulah (Adlam, Ghana)'),
        (286, 'Fulah (Adlam, Gambia)'),
        (287, 'Fulah (Adlam, Guinea)'),
        (288, 'Fulah (Adlam, Guinea-Bissau)'),
        (289, 'Fulah (Adlam, Liberia)'),
        (290, 'Fulah (Adlam, Mauritania)'),
        (291, 'Fulah (Adlam, Niger)'),
        (292, 'Fulah (Adlam, Nigeria)'),
        (293, 'Fulah (Adlam, Sierra Leone)'),
        (294, 'Fulah (Adlam, Senegal)'),
        (295, 'Fulah (Latin)'),
        (296, 'Fulah (Latin, Burkina Faso)'),
        (297, 'Fulah (Latin, Cameroon)'),
        (298, 'Fulah (Latin, Ghana)'),
        (299, 'Fulah (Latin, Gambia)'),
        (300, 'Fulah (Latin, Guinea)'),
        (301, 'Fulah (Latin, Guinea-Bissau)'),
        (302, 'Fulah (Latin, Liberia)'),
        (303, 'Fulah (Latin, Mauritania)'),
        (304, 'Fulah (Latin, Niger)'),
        (305, 'Fulah (Latin, Nigeria)'),
        (306, 'Fulah (Latin, Sierra Leone)'),
        (307, 'Fulah (Latin, Senegal)'),
        (308, 'Finnish'),
        (309, 'Finnish (Finland)'),
        (310, 'Filipino'),
        (311, 'Filipino (Philippines)'),
        (312, 'Faroese'),
        (313, 'Faroese (Denmark)'),
        (314, 'Faroese (Faroe Islands)'),
        (315, 'French'),
        (316, 'French (Belgium)'),
        (317, 'French (Burkina Faso)'),
        (318, 'French (Burundi)'),
        (319, 'French (Benin)'),
        (321, 'French (Canada)'),
        (322, 'French (Congo - Kinshasa)'),
        (323, 'French (Central African Republic)'),
        (324, 'French (Congo - Brazzaville)'),
        (325, 'French (Switzerland)'),
        (327, 'French (Cameroon)'),
        (328, 'French (Djibouti)'),
        (329, 'French (Algeria)'),
        (330, 'French (France)'),
        (331, 'French (Gabon)'),
        (332, 'French (French Guiana)'),
        (333, 'French (Guinea)'),
        (334, 'French (Guadeloupe)'),
        (335, 'French (Equatorial Guinea)'),
        (336, 'French (Haiti)'),
        (337, 'French (Comoros)'),
        (338, 'French (Luxembourg)'),
        (339, 'French (Morocco)'),
        (340, 'French (Monaco)'),
        (341, 'French (St. Martin)'),
        (342, 'French (Madagascar)'),
        (343, 'French (Mali)'),
        (344, 'French (Martinique)'),
        (345, 'French (Mauritania)'),
        (346, 'French (Mauritius)'),
        (347, 'French (New Caledonia)'),
        (348, 'French (Niger)'),
        (349, 'French (French Polynesia)'),
        (350, 'French (St. Pierre & Miquelon)'),
        (352, 'French (Rwanda)'),
        (353, 'French (Seychelles)'),
        (354, 'French (Senegal)'),
        (355, 'French (Syria)'),
        (356, 'French (Chad)'),
        (357, 'French (Togo)'),
        (358, 'French (Tunisia)'),
        (359, 'French (Vanuatu)'),
        (360, 'French (Wallis & Futuna)'),
        (361, 'French (Mayotte)'),
        (362, 'Friulian'),
        (363, 'Friulian (Italy)'),
        (364, 'Western Frisian'),
        (365, 'Western Frisian (Netherlands)'),
        (366, 'Irish'),
        (367, 'Irish (United Kingdom)'),
        (368, 'Irish (Ireland)'),
        (369, 'Scottish Gaelic'),
        (370, 'Scottish Gaelic (United Kingdom)'),
        (371, 'Galician'),
        (372, 'Galician (Spain)'),
        (373, 'Swiss German'),
        (374, 'Swiss German (Switzerland)'),
        (375, 'Swiss German (France)'),
        (376, 'Swiss German (Liechtenstein)'),
        (377, 'Gujarati'),
        (378, 'Gujarati (India)'),
        (379, 'Gusii'),
        (380, 'Gusii (Kenya)'),
        (381, 'Manx'),
        (382, 'Manx (Isle of Man)'),
        (383, 'Hausa'),
        (384, 'Hausa (Ghana)'),
        (385, 'Hausa (Niger)'),
        (386, 'Hausa (Nigeria)'),
        (387, 'Hawaiian'),
        (388, 'Hawaiian (United States)'),
        (389, 'Hebrew'),
        (390, 'Hebrew (Israel)'),
        (391, 'Hindi'),
        (392, 'Hindi (India)'),
        (393, 'Croatian'),
        (394, 'Croatian (Bosnia & Herzegovina)'),
        (395, 'Croatian (Croatia)'),
        (396, 'Upper Sorbian'),
        (397, 'Upper Sorbian (Germany)'),
        (398, 'Hungarian'),
        (399, 'Hungarian (Hungary)'),
        (400, 'Armenian'),
        (401, 'Armenian (Armenia)'),
        (402, 'Interlingua'),
        (403, 'Interlingua (World)'),
        (404, 'Indonesian'),
        (405, 'Indonesian (Indonesia)'),
        (406, 'Igbo'),
        (407, 'Igbo (Nigeria)'),
        (408, 'Sichuan Yi'),
        (409, 'Sichuan Yi (China)'),
        (410, 'Icelandic'),
        (411, 'Icelandic (Iceland)'),
        (412, 'Italian'),
        (413, 'Italian (Switzerland)'),
        (414, 'Italian (Italy)'),
        (415, 'Italian (San Marino)'),
        (416, 'Italian (Vatican City)'),
        (417, 'Japanese'),
        (418, 'Japanese (Japan)'),
        (419, 'Ngomba'),
        (420, 'Ngomba (Cameroon)'),
        (421, 'Machame'),
        (422, 'Machame (Tanzania)'),
        (423, 'Javanese'),
        (424, 'Javanese (Indonesia)'),
        (425, 'Georgian'),
        (426, 'Georgian (Georgia)'),
        (427, 'Kabyle'),
        (428, 'Kabyle (Algeria)'),
        (429, 'Kamba'),
        (430, 'Kamba (Kenya)'),
        (431, 'Makonde'),
        (432, 'Makonde (Tanzania)'),
        (433, 'Kabuverdianu'),
        (434, 'Kabuverdianu (Cape Verde)'),
        (435, 'Koyra Chiini'),
        (436, 'Koyra Chiini (Mali)'),
        (437, 'Kikuyu'),
        (438, 'Kikuyu (Kenya)'),
        (439, 'Kazakh'),
        (440, 'Kazakh (Kazakhstan)'),
        (441, 'Kako'),
        (442, 'Kako (Cameroon)'),
        (443, 'Kalaallisut'),
        (444, 'Kalaallisut (Greenland)'),
        (445, 'Kalenjin'),
        (446, 'Kalenjin (Kenya)'),
        (447, 'Khmer'),
        (448, 'Khmer (Cambodia)'),
        (449, 'Kannada'),
        (450, 'Kannada (India)'),
        (451, 'Korean'),
        (452, 'Korean (North Korea)'),
        (453, 'Korean (South Korea)'),
        (454, 'Konkani'),
        (455, 'Konkani (India)'),
        (456, 'Kashmiri'),
        (457, 'Kashmiri (Arabic)'),
        (458, 'Kashmiri (Arabic, India)'),
        (459, 'Shambala'),
        (460, 'Shambala (Tanzania)'),
        (461, 'Bafia'),
        (462, 'Bafia (Cameroon)'),
        (463, 'Colognian'),
        (464, 'Colognian (Germany)'),
        (465, 'Kurdish'),
        (466, 'Kurdish (Turkey)'),
        (467, 'Cornish'),
        (468, 'Cornish (United Kingdom)'),
        (469, 'Kyrgyz'),
        (470, 'Kyrgyz (Kyrgyzstan)'),
        (471, 'Langi'),
        (472, 'Langi (Tanzania)'),
        (473, 'Luxembourgish'),
        (474, 'Luxembourgish (Luxembourg)'),
        (475, 'Ganda'),
        (476, 'Ganda (Uganda)'),
        (477, 'Lakota'),
        (478, 'Lakota (United States)'),
        (479, 'Lingala'),
        (480, 'Lingala (Angola)'),
        (481, 'Lingala (Congo - Kinshasa)'),
        (482, 'Lingala (Central African Republic)'),
        (483, 'Lingala (Congo - Brazzaville)'),
        (484, 'Lao'),
        (485, 'Lao (Laos)'),
        (486, 'Northern Luri'),
        (487, 'Northern Luri (Iraq)'),
        (488, 'Northern Luri (Iran)'),
        (489, 'Lithuanian'),
        (490, 'Lithuanian (Lithuania)'),
        (491, 'Luba-Katanga'),
        (492, 'Luba-Katanga (Congo - Kinshasa)'),
        (493, 'Luo'),
        (494, 'Luo (Kenya)'),
        (495, 'Luyia'),
        (496, 'Luyia (Kenya)'),
        (497, 'Latvian'),
        (498, 'Latvian (Latvia)'),
        (499, 'Maithili'),
        (500, 'Maithili (India)'),
        (501, 'Masai'),
        (502, 'Masai (Kenya)'),
        (503, 'Masai (Tanzania)'),
        (504, 'Meru'),
        (505, 'Meru (Kenya)'),
        (506, 'Morisyen'),
        (507, 'Morisyen (Mauritius)'),
        (508, 'Malagasy'),
        (509, 'Malagasy (Madagascar)'),
        (510, 'Makhuwa-Meetto'),
        (511, 'Makhuwa-Meetto (Mozambique)'),
        (514, 'Maori'),
        (515, 'Maori (New Zealand)'),
        (516, 'Macedonian'),
        (517, 'Macedonian (North Macedonia)'),
        (518, 'Malayalam'),
        (519, 'Malayalam (India)'),
        (520, 'Mongolian'),
        (521, 'Mongolian (Mongolia)'),
        (522, 'Manipuri'),
        (523, 'Manipuri (Bangla)'),
        (524, 'Manipuri (Bangla, India)'),
        (525, 'Marathi'),
        (526, 'Marathi (India)'),
        (527, 'Malay'),
        (528, 'Malay (Brunei)'),
        (529, 'Malay (Indonesia)'),
        (530, 'Malay (Malaysia)'),
        (531, 'Malay (Singapore)'),
        (532, 'Maltese'),
        (533, 'Maltese (Malta)'),
        (534, 'Mundang'),
        (535, 'Mundang (Cameroon)'),
        (536, 'Burmese'),
        (537, 'Burmese (Myanmar [Burma])'),
        (538, 'Mazanderani'),
        (539, 'Mazanderani (Iran)'),
        (540, 'Nama'),
        (541, 'Nama (Namibia)'),
        (545, 'North Ndebele'),
        (546, 'North Ndebele (Zimbabwe)'),
        (547, 'Low German'),
        (548, 'Low German (Germany)'),
        (549, 'Low German (Netherlands)'),
        (550, 'Nepali'),
        (551, 'Nepali (India)'),
        (552, 'Nepali (Nepal)'),
        (553, 'Dutch'),
        (554, 'Dutch (Aruba)'),
        (555, 'Dutch (Belgium)'),
        (556, 'Dutch (Caribbean Netherlands)'),
        (558, 'Dutch (Netherlands)'),
        (559, 'Dutch (Suriname)'),
        (560, 'Dutch (Sint Maarten)'),
        (561, 'Kwasio'),
        (562, 'Kwasio (Cameroon)'),
        (563, 'Norwegian Nynorsk'),
        (564, 'Norwegian Nynorsk (Norway)'),
        (565, 'Ngiemboon'),
        (566, 'Ngiemboon (Cameroon)'),
        (567, 'Nuer'),
        (568, 'Nuer (South Sudan)'),
        (569, 'Nyankole'),
        (570, 'Nyankole (Uganda)'),
        (571, 'Oromo'),
        (572, 'Oromo (Ethiopia)'),
        (573, 'Oromo (Kenya)'),
        (574, 'Odia'),
        (575, 'Odia (India)'),
        (576, 'Ossetic'),
        (577, 'Ossetic (Georgia)'),
        (578, 'Ossetic (Russia)'),
        (579, 'Punjabi'),
        (580, 'Punjabi (Arabic)'),
        (581, 'Punjabi (Arabic, Pakistan)'),
        (582, 'Punjabi (Gurmukhi)'),
        (583, 'Punjabi (Gurmukhi, India)'),
        (584, 'Nigerian Pidgin'),
        (585, 'Nigerian Pidgin (Nigeria)'),
        (586, 'Polish'),
        (587, 'Polish (Poland)'),
        (588, 'Pashto'),
        (589, 'Pashto (Afghanistan)'),
        (590, 'Pashto (Pakistan)'),
        (591, 'Portuguese'),
        (592, 'Portuguese (Angola)'),
        (593, 'Portuguese (Brazil)'),
        (594, 'Portuguese (Switzerland)'),
        (595, 'Portuguese (Cape Verde)'),
        (596, 'Portuguese (Equatorial Guinea)'),
        (597, 'Portuguese (Guinea-Bissau)'),
        (598, 'Portuguese (Luxembourg)'),
        (599, 'Portuguese (Macao SAR China)'),
        (600, 'Portuguese (Mozambique)'),
        (601, 'Portuguese (Portugal)'),
        (603, 'Portuguese (Timor-Leste)'),
        (604, 'Quechua'),
        (605, 'Quechua (Bolivia)'),
        (606, 'Quechua (Ecuador)'),
        (607, 'Quechua (Peru)'),
        (608, 'Romansh'),
        (609, 'Romansh (Switzerland)'),
        (610, 'Rundi'),
        (611, 'Rundi (Burundi)'),
        (612, 'Romanian'),
        (613, 'Romanian (Moldova)'),
        (614, 'Romanian (Romania)'),
        (615, 'Rombo'),
        (616, 'Rombo (Tanzania)'),
        (617, 'Russian'),
        (618, 'Russian (Belarus)'),
        (619, 'Russian (Kyrgyzstan)'),
        (620, 'Russian (Kazakhstan)'),
        (621, 'Russian (Moldova)'),
        (622, 'Russian (Russia)'),
        (623, 'Russian (Ukraine)'),
        (624, 'Kinyarwanda'),
        (625, 'Kinyarwanda (Rwanda)'),
        (626, 'Rwa'),
        (627, 'Rwa (Tanzania)'),
        (628, 'Sakha'),
        (629, 'Sakha (Russia)'),
        (630, 'Samburu'),
        (631, 'Samburu (Kenya)'),
        (632, 'Santali'),
        (633, 'Santali (Ol Chiki)'),
        (634, 'Santali (Ol Chiki, India)'),
        (635, 'Sangu'),
        (636, 'Sangu (Tanzania)'),
        (637, 'Sindhi'),
        (638, 'Sindhi (Arabic)'),
        (639, 'Sindhi (Arabic, Pakistan)'),
        (640, 'Sindhi (Devanagari)'),
        (641, 'Sindhi (Devanagari, India)'),
        (642, 'Northern Sami'),
        (643, 'Northern Sami (Finland)'),
        (644, 'Northern Sami (Norway)'),
        (645, 'Northern Sami (Sweden)'),
        (646, 'Sena'),
        (647, 'Sena (Mozambique)'),
        (648, 'Koyraboro Senni'),
        (649, 'Koyraboro Senni (Mali)'),
        (650, 'Sango'),
        (651, 'Sango (Central African Republic)'),
        (652, 'Tachelhit'),
        (653, 'Tachelhit (Latin)'),
        (654, 'Tachelhit (Latin, Morocco)'),
        (655, 'Tachelhit (Tifinagh)'),
        (656, 'Tachelhit (Tifinagh, Morocco)'),
        (657, 'Sinhala'),
        (658, 'Sinhala (Sri Lanka)'),
        (659, 'Slovak'),
        (660, 'Slovak (Slovakia)'),
        (661, 'Slovenian'),
        (662, 'Slovenian (Slovenia)'),
        (663, 'Inari Sami'),
        (664, 'Inari Sami (Finland)'),
        (665, 'Shona'),
        (666, 'Shona (Zimbabwe)'),
        (667, 'Somali'),
        (668, 'Somali (Djibouti)'),
        (669, 'Somali (Ethiopia)'),
        (670, 'Somali (Kenya)'),
        (671, 'Somali (Somalia)'),
        (672, 'Albanian'),
        (673, 'Albanian (Albania)'),
        (674, 'Albanian (North Macedonia)'),
        (675, 'Albanian (Kosovo)'),
        (676, 'Serbian'),
        (677, 'Serbian (Cyrillic)'),
        (678, 'Serbian (Cyrillic, Bosnia & Herzegovina)'),
        (679, 'Serbian (Cyrillic, Montenegro)'),
        (680, 'Serbian (Cyrillic, Serbia)'),
        (681, 'Serbian (Cyrillic, Kosovo)'),
        (682, 'Serbian (Latin)'),
        (683, 'Serbian (Latin, Bosnia & Herzegovina)'),
        (684, 'Serbian (Latin, Montenegro)'),
        (685, 'Serbian (Latin, Serbia)'),
        (686, 'Serbian (Latin, Kosovo)'),
        (687, 'Sundanese'),
        (688, 'Sundanese (Latin)'),
        (689, 'Sundanese (Latin, Indonesia)'),
        (690, 'Swedish'),
        (692, 'Swedish (Finland)'),
        (693, 'Swedish (Sweden)'),
        (694, 'Swahili'),
        (695, 'Swahili (Congo - Kinshasa)'),
        (696, 'Swahili (Kenya)'),
        (697, 'Swahili (Tanzania)'),
        (698, 'Swahili (Uganda)'),
        (699, 'Tamil'),
        (700, 'Tamil (India)'),
        (701, 'Tamil (Sri Lanka)'),
        (702, 'Tamil (Malaysia)'),
        (703, 'Tamil (Singapore)'),
        (704, 'Telugu'),
        (705, 'Telugu (India)'),
        (706, 'Teso'),
        (707, 'Teso (Kenya)'),
        (708, 'Teso (Uganda)'),
        (709, 'Tajik'),
        (710, 'Tajik (Tajikistan)'),
        (711, 'Thai'),
        (712, 'Thai (Thailand)'),
        (713, 'Tigrinya'),
        (714, 'Tigrinya (Eritrea)'),
        (715, 'Tigrinya (Ethiopia)'),
        (716, 'Turkmen'),
        (717, 'Turkmen (Turkmenistan)'),
        (718, 'Tongan'),
        (719, 'Tongan (Tonga)'),
        (720, 'Turkish'),
        (721, 'Turkish (Cyprus)'),
        (722, 'Turkish (Turkey)'),
        (723, 'Tatar'),
        (724, 'Tatar (Russia)'),
        (725, 'Tasawaq'),
        (726, 'Tasawaq (Niger)'),
        (727, 'Central Atlas Tamazight'),
        (728, 'Central Atlas Tamazight (Morocco)'),
        (729, 'Uyghur'),
        (730, 'Uyghur (China)'),
        (731, 'Ukrainian'),
        (732, 'Ukrainian (Ukraine)'),
        (733, 'Urdu'),
        (734, 'Urdu (India)'),
        (735, 'Urdu (Pakistan)'),
        (736, 'Uzbek'),
        (737, 'Uzbek (Arabic)'),
        (738, 'Uzbek (Arabic, Afghanistan)'),
        (739, 'Uzbek (Cyrillic)'),
        (740, 'Uzbek (Cyrillic, Uzbekistan)'),
        (741, 'Uzbek (Latin)'),
        (742, 'Uzbek (Latin, Uzbekistan)'),
        (743, 'Vai'),
        (744, 'Vai (Latin)'),
        (745, 'Vai (Latin, Liberia)'),
        (746, 'Vai (Vai)'),
        (747, 'Vai (Vai, Liberia)'),
        (748, 'Vietnamese'),
        (749, 'Vietnamese (Vietnam)'),
        (750, 'Vunjo'),
        (751, 'Vunjo (Tanzania)'),
        (752, 'Walser'),
        (753, 'Walser (Switzerland)'),
        (754, 'Wolof'),
        (755, 'Wolof (Senegal)'),
        (756, 'Xhosa'),
        (757, 'Xhosa (South Africa)'),
        (758, 'Soga'),
        (759, 'Soga (Uganda)'),
        (760, 'Yangben'),
        (761, 'Yangben (Cameroon)'),
        (762, 'Yiddish'),
        (763, 'Yiddish (World)'),
        (764, 'Yoruba'),
        (765, 'Yoruba (Benin)'),
        (766, 'Yoruba (Nigeria)'),
        (767, 'Cantonese'),
        (768, 'Cantonese (Simplified)'),
        (769, 'Cantonese (Simplified, China)'),
        (770, 'Cantonese (Traditional)'),
        (771, 'Cantonese (Traditional, Hong Kong SAR China)'),
        (772, 'Standard Moroccan Tamazight'),
        (773, 'Standard Moroccan Tamazight (Morocco)'),
        (774, 'Chinese'),
        (775, 'Chinese (Simplified)'),
        (776, 'Chinese (Simplified, China)'),
        (777, 'Chinese (Simplified, Hong Kong SAR China)'),
        (778, 'Chinese (Simplified, Macao SAR China)'),
        (779, 'Chinese (Simplified, Singapore)'),
        (780, 'Chinese (Traditional)'),
        (781, 'Chinese (Traditional, Hong Kong SAR China)'),
        (782, 'Chinese (Traditional, Macao SAR China)'),
        (783, 'Chinese (Traditional, Taiwan)'),
        (784, 'Zulu'),
        (785, 'Zulu (South Africa)')
    )
    -- Populate pg_description table using the above auto-generated OIDs for collations.
    -- Use collation list order as the link to properly match collations with descriptions.
    INSERT INTO pg_catalog.pg_description (
      objoid, classoid, objsubid, description
    ) SELECT o.pg_coll_oid, 3456, 0, d.description
      FROM (
        SELECT
          ROW_NUMBER() OVER (ORDER BY pg_coll_oid) AS row_number,
          pg_coll_oid
        FROM tmp_oids
      ) o
      INNER JOIN tmp_descr d ON o.row_number = d.row_number;

  END IF;
END $$;
